Class: Aws::Transfer::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Transfer::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-transfer/client.rb,
sig/client.rbs
Overview
An API client for Transfer. To construct a client, you need to configure a :region and :credentials.
client = Aws::Transfer::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAccessResponseSuccess, _CreateAgreementResponseSuccess, _CreateConnectorResponseSuccess, _CreateProfileResponseSuccess, _CreateServerResponseSuccess, _CreateUserResponseSuccess, _CreateWebAppResponseSuccess, _CreateWorkflowResponseSuccess, _DescribeAccessResponseSuccess, _DescribeAgreementResponseSuccess, _DescribeCertificateResponseSuccess, _DescribeConnectorResponseSuccess, _DescribeExecutionResponseSuccess, _DescribeHostKeyResponseSuccess, _DescribeProfileResponseSuccess, _DescribeSecurityPolicyResponseSuccess, _DescribeServerResponseSuccess, _DescribeUserResponseSuccess, _DescribeWebAppCustomizationResponseSuccess, _DescribeWebAppResponseSuccess, _DescribeWorkflowResponseSuccess, _ImportCertificateResponseSuccess, _ImportHostKeyResponseSuccess, _ImportSshPublicKeyResponseSuccess, _ListAccessesResponseSuccess, _ListAgreementsResponseSuccess, _ListCertificatesResponseSuccess, _ListConnectorsResponseSuccess, _ListExecutionsResponseSuccess, _ListFileTransferResultsResponseSuccess, _ListHostKeysResponseSuccess, _ListProfilesResponseSuccess, _ListSecurityPoliciesResponseSuccess, _ListServersResponseSuccess, _ListTagsForResourceResponseSuccess, _ListUsersResponseSuccess, _ListWebAppsResponseSuccess, _ListWorkflowsResponseSuccess, _SendWorkflowStepStateResponseSuccess, _StartDirectoryListingResponseSuccess, _StartFileTransferResponseSuccess, _StartRemoteDeleteResponseSuccess, _StartRemoteMoveResponseSuccess, _TestConnectionResponseSuccess, _TestIdentityProviderResponseSuccess, _UpdateAccessResponseSuccess, _UpdateAgreementResponseSuccess, _UpdateCertificateResponseSuccess, _UpdateConnectorResponseSuccess, _UpdateHostKeyResponseSuccess, _UpdateProfileResponseSuccess, _UpdateServerResponseSuccess, _UpdateUserResponseSuccess, _UpdateWebAppCustomizationResponseSuccess, _UpdateWebAppResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_access(params = {}) ⇒ Types::CreateAccessResponse
Used by administrators to choose which groups in the directory should have access to upload and download files over the enabled protocols using Transfer Family.
-
#create_agreement(params = {}) ⇒ Types::CreateAgreementResponse
Creates an agreement.
-
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates the connector, which captures the parameters for a connection for the AS2 or SFTP protocol.
-
#create_profile(params = {}) ⇒ Types::CreateProfileResponse
Creates the local or partner profile to use for AS2 transfers.
-
#create_server(params = {}) ⇒ Types::CreateServerResponse
Instantiates an auto-scaling virtual server based on the selected file transfer protocol in Amazon Web Services.
-
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user and associates them with an existing file transfer protocol-enabled server.
-
#create_web_app(params = {}) ⇒ Types::CreateWebAppResponse
Creates a web app based on specified parameters, and returns the ID for the new web app.
-
#create_workflow(params = {}) ⇒ Types::CreateWorkflowResponse
Allows you to create a workflow with specified steps and step details the workflow invokes after file transfer completes.
-
#delete_access(params = {}) ⇒ Struct
Allows you to delete the access specified in the
ServerIDandExternalIDparameters. -
#delete_agreement(params = {}) ⇒ Struct
Delete the agreement that's specified in the provided
AgreementId. -
#delete_certificate(params = {}) ⇒ Struct
Deletes the certificate that's specified in the
CertificateIdparameter. -
#delete_connector(params = {}) ⇒ Struct
Deletes the connector that's specified in the provided
ConnectorId. -
#delete_host_key(params = {}) ⇒ Struct
Deletes the host key that's specified in the
HostKeyIdparameter. -
#delete_profile(params = {}) ⇒ Struct
Deletes the profile that's specified in the
ProfileIdparameter. -
#delete_server(params = {}) ⇒ Struct
Deletes the file transfer protocol-enabled server that you specify.
-
#delete_ssh_public_key(params = {}) ⇒ Struct
Deletes a user's Secure Shell (SSH) public key.
-
#delete_user(params = {}) ⇒ Struct
Deletes the user belonging to a file transfer protocol-enabled server you specify.
-
#delete_web_app(params = {}) ⇒ Struct
Deletes the specified web app.
-
#delete_web_app_customization(params = {}) ⇒ Struct
Deletes the
WebAppCustomizationobject that corresponds to the web app ID specified. -
#delete_workflow(params = {}) ⇒ Struct
Deletes the specified workflow.
-
#describe_access(params = {}) ⇒ Types::DescribeAccessResponse
Describes the access that is assigned to the specific file transfer protocol-enabled server, as identified by its
ServerIdproperty and itsExternalId. -
#describe_agreement(params = {}) ⇒ Types::DescribeAgreementResponse
Describes the agreement that's identified by the
AgreementId. -
#describe_certificate(params = {}) ⇒ Types::DescribeCertificateResponse
Describes the certificate that's identified by the
CertificateId. -
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Describes the connector that's identified by the
ConnectorId.. -
#describe_execution(params = {}) ⇒ Types::DescribeExecutionResponse
You can use
DescribeExecutionto check the details of the execution of the specified workflow. -
#describe_host_key(params = {}) ⇒ Types::DescribeHostKeyResponse
Returns the details of the host key that's specified by the
HostKeyIdandServerId. -
#describe_profile(params = {}) ⇒ Types::DescribeProfileResponse
Returns the details of the profile that's specified by the
ProfileId. -
#describe_security_policy(params = {}) ⇒ Types::DescribeSecurityPolicyResponse
Describes the security policy that is attached to your server or SFTP connector.
-
#describe_server(params = {}) ⇒ Types::DescribeServerResponse
Describes a file transfer protocol-enabled server that you specify by passing the
ServerIdparameter. -
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Describes the user assigned to the specific file transfer protocol-enabled server, as identified by its
ServerIdproperty. -
#describe_web_app(params = {}) ⇒ Types::DescribeWebAppResponse
Describes the web app that's identified by
WebAppId. -
#describe_web_app_customization(params = {}) ⇒ Types::DescribeWebAppCustomizationResponse
Describes the web app customization object that's identified by
WebAppId. -
#describe_workflow(params = {}) ⇒ Types::DescribeWorkflowResponse
Describes the specified workflow.
-
#import_certificate(params = {}) ⇒ Types::ImportCertificateResponse
Imports the signing and encryption certificates that you need to create local (AS2) profiles and partner profiles.
-
#import_host_key(params = {}) ⇒ Types::ImportHostKeyResponse
Adds a host key to the server that's specified by the
ServerIdparameter. -
#import_ssh_public_key(params = {}) ⇒ Types::ImportSshPublicKeyResponse
Adds a Secure Shell (SSH) public key to a Transfer Family user identified by a
UserNamevalue assigned to the specific file transfer protocol-enabled server, identified byServerId. -
#list_accesses(params = {}) ⇒ Types::ListAccessesResponse
Lists the details for all the accesses you have on your server.
-
#list_agreements(params = {}) ⇒ Types::ListAgreementsResponse
Returns a list of the agreements for the server that's identified by the
ServerIdthat you supply. -
#list_certificates(params = {}) ⇒ Types::ListCertificatesResponse
Returns a list of the current certificates that have been imported into Transfer Family.
-
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Lists the connectors for the specified Region.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
Lists all in-progress executions for the specified workflow.
-
#list_file_transfer_results(params = {}) ⇒ Types::ListFileTransferResultsResponse
Returns real-time updates and detailed information on the status of each individual file being transferred in a specific file transfer operation.
-
#list_host_keys(params = {}) ⇒ Types::ListHostKeysResponse
Returns a list of host keys for the server that's specified by the
ServerIdparameter. -
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Returns a list of the profiles for your system.
-
#list_security_policies(params = {}) ⇒ Types::ListSecurityPoliciesResponse
Lists the security policies that are attached to your servers and SFTP connectors.
-
#list_servers(params = {}) ⇒ Types::ListServersResponse
Lists the file transfer protocol-enabled servers that are associated with your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify.
-
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists the users for a file transfer protocol-enabled server that you specify by passing the
ServerIdparameter. -
#list_web_apps(params = {}) ⇒ Types::ListWebAppsResponse
Lists all web apps associated with your Amazon Web Services account for your current region.
-
#list_workflows(params = {}) ⇒ Types::ListWorkflowsResponse
Lists all workflows associated with your Amazon Web Services account for your current region.
-
#send_workflow_step_state(params = {}) ⇒ Struct
Sends a callback for asynchronous custom steps.
-
#start_directory_listing(params = {}) ⇒ Types::StartDirectoryListingResponse
Retrieves a list of the contents of a directory from a remote SFTP server.
-
#start_file_transfer(params = {}) ⇒ Types::StartFileTransferResponse
Begins a file transfer between local Amazon Web Services storage and a remote AS2 or SFTP server.
-
#start_remote_delete(params = {}) ⇒ Types::StartRemoteDeleteResponse
Deletes a file or directory on the remote SFTP server.
-
#start_remote_move(params = {}) ⇒ Types::StartRemoteMoveResponse
Moves or renames a file or directory on the remote SFTP server.
-
#start_server(params = {}) ⇒ Struct
Changes the state of a file transfer protocol-enabled server from
OFFLINEtoONLINE. -
#stop_server(params = {}) ⇒ Struct
Changes the state of a file transfer protocol-enabled server from
ONLINEtoOFFLINE. -
#tag_resource(params = {}) ⇒ Struct
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN).
-
#test_connection(params = {}) ⇒ Types::TestConnectionResponse
Tests whether your SFTP connector is set up successfully.
-
#test_identity_provider(params = {}) ⇒ Types::TestIdentityProviderResponse
If the
IdentityProviderTypeof a file transfer protocol-enabled server isAWS_DIRECTORY_SERVICEorAPI_Gateway, tests whether your identity provider is set up successfully. -
#untag_resource(params = {}) ⇒ Struct
Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN).
-
#update_access(params = {}) ⇒ Types::UpdateAccessResponse
Allows you to update parameters for the access specified in the
ServerIDandExternalIDparameters. -
#update_agreement(params = {}) ⇒ Types::UpdateAgreementResponse
Updates some of the parameters for an existing agreement.
-
#update_certificate(params = {}) ⇒ Types::UpdateCertificateResponse
Updates the active and inactive dates for a certificate.
-
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates some of the parameters for an existing connector.
-
#update_host_key(params = {}) ⇒ Types::UpdateHostKeyResponse
Updates the description for the host key that's specified by the
ServerIdandHostKeyIdparameters. -
#update_profile(params = {}) ⇒ Types::UpdateProfileResponse
Updates some of the parameters for an existing profile.
-
#update_server(params = {}) ⇒ Types::UpdateServerResponse
Updates the file transfer protocol-enabled server's properties after that server has been created.
-
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Assigns new properties to a user.
-
#update_web_app(params = {}) ⇒ Types::UpdateWebAppResponse
Assigns new properties to a web app.
-
#update_web_app_customization(params = {}) ⇒ Types::UpdateWebAppCustomizationResponse
Assigns new customization properties to a web app.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-transfer/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5911 5912 5913 |
# File 'lib/aws-sdk-transfer/client.rb', line 5911 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5914 5915 5916 |
# File 'lib/aws-sdk-transfer/client.rb', line 5914 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-transfer/client.rb', line 5769 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Transfer') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-transfer' context[:gem_version] = '1.146.0' Seahorse::Client::Request.new(handlers, context) end |
#create_access(params = {}) ⇒ Types::CreateAccessResponse
Used by administrators to choose which groups in the directory should
have access to upload and download files over the enabled protocols
using Transfer Family. For example, a Microsoft Active Directory might
contain 50,000 users, but only a small fraction might need the ability
to transfer files to the server. An administrator can use
CreateAccess to limit the access to the correct set of users who
need this ability.
88 |
# File 'sig/client.rbs', line 88
def create_access: (
|
#create_agreement(params = {}) ⇒ Types::CreateAgreementResponse
Creates an agreement. An agreement is a bilateral trading partner agreement, or partnership, between an Transfer Family server and an AS2 process. The agreement defines the file and message transfer relationship between the server and the AS2 process. To define an agreement, Transfer Family combines a server, local profile, partner profile, certificate, and other attributes.
The partner is identified with the PartnerProfileId, and the AS2
process is identified with the LocalProfileId.
BaseDirectory or CustomDirectories, but not both.
Specifying both causes the command to fail.
115 |
# File 'sig/client.rbs', line 115
def create_agreement: (
|
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates the connector, which captures the parameters for a connection for the AS2 or SFTP protocol. For AS2, the connector is required for sending files to an externally hosted AS2 server. For SFTP, the connector is required when sending files to an SFTP server or receiving files from an SFTP server. For more details about connectors, see Configure AS2 connectors and Create SFTP connectors.
As2Config) or SFTP (SftpConfig).
146 |
# File 'sig/client.rbs', line 146
def create_connector: (
|
#create_profile(params = {}) ⇒ Types::CreateProfileResponse
Creates the local or partner profile to use for AS2 transfers.
179 |
# File 'sig/client.rbs', line 179
def create_profile: (
|
#create_server(params = {}) ⇒ Types::CreateServerResponse
Instantiates an auto-scaling virtual server based on the selected file
transfer protocol in Amazon Web Services. When you make updates to
your file transfer protocol-enabled server or when you work with
users, use the service-generated ServerId property that is assigned
to the newly created server.
197 |
# File 'sig/client.rbs', line 197
def create_server: (
|
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user and associates them with an existing file transfer
protocol-enabled server. You can only create and associate users with
servers that have the IdentityProviderType set to SERVICE_MANAGED.
Using parameters for CreateUser, you can specify the user name, set
the home directory, store the user's public key, and assign the
user's Identity and Access Management (IAM) role. You can also
optionally add a session policy, and assign metadata with tags that
can be used to group and search for users.
244 |
# File 'sig/client.rbs', line 244
def create_user: (
|
#create_web_app(params = {}) ⇒ Types::CreateWebAppResponse
Creates a web app based on specified parameters, and returns the ID for the new web app. You can configure the web app to be publicly accessible or hosted within a VPC.
For more information about using VPC endpoints with Transfer Family, see Create a Transfer Family web app in a VPC.
278 |
# File 'sig/client.rbs', line 278
def create_web_app: (
|
#create_workflow(params = {}) ⇒ Types::CreateWorkflowResponse
Allows you to create a workflow with specified steps and step details
the workflow invokes after file transfer completes. After creating a
workflow, you can associate the workflow created with any transfer
servers by specifying the workflow-details field in CreateServer
and UpdateServer operations.
312 |
# File 'sig/client.rbs', line 312
def create_workflow: (
|
#delete_access(params = {}) ⇒ Struct
Allows you to delete the access specified in the ServerID and
ExternalID parameters.
330 |
# File 'sig/client.rbs', line 330
def delete_access: (
|
#delete_agreement(params = {}) ⇒ Struct
Delete the agreement that's specified in the provided AgreementId.
337 |
# File 'sig/client.rbs', line 337
def delete_agreement: (
|
#delete_certificate(params = {}) ⇒ Struct
Deletes the certificate that's specified in the CertificateId
parameter.
344 |
# File 'sig/client.rbs', line 344
def delete_certificate: (
|
#delete_connector(params = {}) ⇒ Struct
Deletes the connector that's specified in the provided ConnectorId.
350 |
# File 'sig/client.rbs', line 350
def delete_connector: (
|
#delete_host_key(params = {}) ⇒ Struct
Deletes the host key that's specified in the HostKeyId parameter.
356 |
# File 'sig/client.rbs', line 356
def delete_host_key: (
|
#delete_profile(params = {}) ⇒ Struct
Deletes the profile that's specified in the ProfileId parameter.
363 |
# File 'sig/client.rbs', line 363
def delete_profile: (
|
#delete_server(params = {}) ⇒ Struct
Deletes the file transfer protocol-enabled server that you specify.
No response returns from this operation.
369 |
# File 'sig/client.rbs', line 369
def delete_server: (
|
#delete_ssh_public_key(params = {}) ⇒ Struct
Deletes a user's Secure Shell (SSH) public key.
375 |
# File 'sig/client.rbs', line 375
def delete_ssh_public_key: (
|
#delete_user(params = {}) ⇒ Struct
Deletes the user belonging to a file transfer protocol-enabled server you specify.
No response returns from this operation.
383 |
# File 'sig/client.rbs', line 383
def delete_user: (
|
#delete_web_app(params = {}) ⇒ Struct
Deletes the specified web app.
390 |
# File 'sig/client.rbs', line 390
def delete_web_app: (
|
#delete_web_app_customization(params = {}) ⇒ Struct
Deletes the WebAppCustomization object that corresponds to the web
app ID specified.
396 |
# File 'sig/client.rbs', line 396
def delete_web_app_customization: (
|
#delete_workflow(params = {}) ⇒ Struct
Deletes the specified workflow.
402 |
# File 'sig/client.rbs', line 402
def delete_workflow: (
|
#describe_access(params = {}) ⇒ Types::DescribeAccessResponse
Describes the access that is assigned to the specific file transfer
protocol-enabled server, as identified by its ServerId property and
its ExternalId.
The response from this call returns the properties of the access that
is associated with the ServerId value that was specified.
413 |
# File 'sig/client.rbs', line 413
def describe_access: (
|
#describe_agreement(params = {}) ⇒ Types::DescribeAgreementResponse
Describes the agreement that's identified by the AgreementId.
424 |
# File 'sig/client.rbs', line 424
def describe_agreement: (
|
#describe_certificate(params = {}) ⇒ Types::DescribeCertificateResponse
Describes the certificate that's identified by the CertificateId.
DaysUntilExpiry for imported certificates. This metric tracks
the number of days until the certificate expires based on the
InactiveDate. The metric is available in the AWS/Transfer
namespace and includes the CertificateId as a dimension.
435 |
# File 'sig/client.rbs', line 435
def describe_certificate: (
|
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Describes the connector that's identified by the ConnectorId.
445 |
# File 'sig/client.rbs', line 445
def describe_connector: (
|
#describe_execution(params = {}) ⇒ Types::DescribeExecutionResponse
You can use DescribeExecution to check the details of the execution
of the specified workflow.
If you provide an ID for an execution that is not in progress, or if
the execution doesn't match the specified workflow ID, you receive a
ResourceNotFound exception.
456 |
# File 'sig/client.rbs', line 456
def describe_execution: (
|
#describe_host_key(params = {}) ⇒ Types::DescribeHostKeyResponse
Returns the details of the host key that's specified by the
HostKeyId and ServerId.
467 |
# File 'sig/client.rbs', line 467
def describe_host_key: (
|
#describe_profile(params = {}) ⇒ Types::DescribeProfileResponse
Returns the details of the profile that's specified by the
ProfileId.
478 |
# File 'sig/client.rbs', line 478
def describe_profile: (
|
#describe_security_policy(params = {}) ⇒ Types::DescribeSecurityPolicyResponse
Describes the security policy that is attached to your server or SFTP connector. The response contains a description of the security policy's properties. For more information about security policies, see Working with security policies for servers or Working with security policies for SFTP connectors.
488 |
# File 'sig/client.rbs', line 488
def describe_security_policy: (
|
#describe_server(params = {}) ⇒ Types::DescribeServerResponse
Describes a file transfer protocol-enabled server that you specify by
passing the ServerId parameter.
The response contains a description of a server's properties. When
you set EndpointType to VPC, the response will contain the
EndpointDetails.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* server_offline
* server_online
498 |
# File 'sig/client.rbs', line 498
def describe_server: (
|
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Describes the user assigned to the specific file transfer
protocol-enabled server, as identified by its ServerId property.
The response from this call returns the properties of the user
associated with the ServerId value that was specified.
509 |
# File 'sig/client.rbs', line 509
def describe_user: (
|
#describe_web_app(params = {}) ⇒ Types::DescribeWebAppResponse
Describes the web app that's identified by WebAppId. The response
includes endpoint configuration details such as whether the web app is
publicly accessible or VPC hosted.
For more information about using VPC endpoints with Transfer Family, see Create a Transfer Family web app in a VPC.
520 |
# File 'sig/client.rbs', line 520
def describe_web_app: (
|
#describe_web_app_customization(params = {}) ⇒ Types::DescribeWebAppCustomizationResponse
Describes the web app customization object that's identified by
WebAppId.
530 |
# File 'sig/client.rbs', line 530
def describe_web_app_customization: (
|
#describe_workflow(params = {}) ⇒ Types::DescribeWorkflowResponse
Describes the specified workflow.
540 |
# File 'sig/client.rbs', line 540
def describe_workflow: (
|
#import_certificate(params = {}) ⇒ Types::ImportCertificateResponse
Imports the signing and encryption certificates that you need to create local (AS2) profiles and partner profiles.
You can import both the certificate and its chain in the Certificate
parameter.
After importing a certificate, Transfer Family automatically creates a
Amazon CloudWatch metric called DaysUntilExpiry that tracks the
number of days until the certificate expires. The metric is based on
the InactiveDate parameter and is published daily in the
AWS/Transfer namespace.
It can take up to a full day after importing a certificate for
Transfer Family to emit the DaysUntilExpiry metric to your account.
Certificate parameter to upload both the certificate
and its chain, don't use the CertificateChain parameter.
CloudWatch monitoring
The DaysUntilExpiry metric includes the following specifications:
-
Units: Count (days)
-
Dimensions:
CertificateId(always present),Description(if provided during certificate import) -
Statistics: Minimum, Maximum, Average
-
Frequency: Published daily
550 |
# File 'sig/client.rbs', line 550
def import_certificate: (
|
#import_host_key(params = {}) ⇒ Types::ImportHostKeyResponse
Adds a host key to the server that's specified by the ServerId
parameter.
573 |
# File 'sig/client.rbs', line 573
def import_host_key: (
|
#import_ssh_public_key(params = {}) ⇒ Types::ImportSshPublicKeyResponse
Adds a Secure Shell (SSH) public key to a Transfer Family user
identified by a UserName value assigned to the specific file
transfer protocol-enabled server, identified by ServerId.
The response returns the UserName value, the ServerId value, and
the name of the SshPublicKeyId.
593 |
# File 'sig/client.rbs', line 593
def import_ssh_public_key: (
|
#list_accesses(params = {}) ⇒ Types::ListAccessesResponse
Lists the details for all the accesses you have on your server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
607 |
# File 'sig/client.rbs', line 607
def list_accesses: (
|
#list_agreements(params = {}) ⇒ Types::ListAgreementsResponse
Returns a list of the agreements for the server that's identified by
the ServerId that you supply. If you want to limit the results to a
certain number, supply a value for the MaxResults parameter. If you
ran the command previously and received a value for NextToken, you
can supply that value to continue listing agreements from where you
left off.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
620 |
# File 'sig/client.rbs', line 620
def list_agreements: (
|
#list_certificates(params = {}) ⇒ Types::ListCertificatesResponse
Returns a list of the current certificates that have been imported
into Transfer Family. If you want to limit the results to a certain
number, supply a value for the MaxResults parameter. If you ran the
command previously and received a value for the NextToken parameter,
you can supply that value to continue listing certificates from where
you left off.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
633 |
# File 'sig/client.rbs', line 633
def list_certificates: (
|
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Lists the connectors for the specified Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
645 |
# File 'sig/client.rbs', line 645
def list_connectors: (
|
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
Lists all in-progress executions for the specified workflow.
ListExecutions returns
a ResourceNotFound exception.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
658 |
# File 'sig/client.rbs', line 658
def list_executions: (
|
#list_file_transfer_results(params = {}) ⇒ Types::ListFileTransferResultsResponse
Returns real-time updates and detailed information on the status of
each individual file being transferred in a specific file transfer
operation. You specify the file transfer by providing its
ConnectorId and its TransferId.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
671 |
# File 'sig/client.rbs', line 671
def list_file_transfer_results: (
|
#list_host_keys(params = {}) ⇒ Types::ListHostKeysResponse
Returns a list of host keys for the server that's specified by the
ServerId parameter.
686 |
# File 'sig/client.rbs', line 686
def list_host_keys: (
|
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Returns a list of the profiles for your system. If you want to limit
the results to a certain number, supply a value for the MaxResults
parameter. If you ran the command previously and received a value for
NextToken, you can supply that value to continue listing profiles
from where you left off.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
699 |
# File 'sig/client.rbs', line 699
def list_profiles: (
|
#list_security_policies(params = {}) ⇒ Types::ListSecurityPoliciesResponse
Lists the security policies that are attached to your servers and SFTP connectors. For more information about security policies, see Working with security policies for servers or Working with security policies for SFTP connectors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
712 |
# File 'sig/client.rbs', line 712
def list_security_policies: (
|
#list_servers(params = {}) ⇒ Types::ListServersResponse
Lists the file transfer protocol-enabled servers that are associated with your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
724 |
# File 'sig/client.rbs', line 724
def list_servers: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The resource can be a user, server, or role.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
737 |
# File 'sig/client.rbs', line 737
def list_tags_for_resource: (
|
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists the users for a file transfer protocol-enabled server that you
specify by passing the ServerId parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
751 |
# File 'sig/client.rbs', line 751
def list_users: (
|
#list_web_apps(params = {}) ⇒ Types::ListWebAppsResponse
Lists all web apps associated with your Amazon Web Services account for your current region. The response includes the endpoint type for each web app, showing whether it is publicly accessible or VPC hosted.
For more information about using VPC endpoints with Transfer Family, see Create a Transfer Family web app in a VPC.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
764 |
# File 'sig/client.rbs', line 764
def list_web_apps: (
|
#list_workflows(params = {}) ⇒ Types::ListWorkflowsResponse
Lists all workflows associated with your Amazon Web Services account for your current region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
776 |
# File 'sig/client.rbs', line 776
def list_workflows: (
|
#send_workflow_step_state(params = {}) ⇒ Struct
Sends a callback for asynchronous custom steps.
The ExecutionId, WorkflowId, and Token are passed to the target
resource during execution of a custom step of a workflow. You must
include those with their callback as well as providing a status.
786 |
# File 'sig/client.rbs', line 786
def send_workflow_step_state: (
|
#start_directory_listing(params = {}) ⇒ Types::StartDirectoryListingResponse
Retrieves a list of the contents of a directory from a remote SFTP
server. You specify the connector ID, the output path, and the remote
directory path. You can also specify the optional MaxItems value to
control the maximum number of items that are listed from the remote
directory. This API returns a list of all files and directories in the
remote directory (up to the maximum value), but does not return files
or folders in sub-directories. That is, it only returns a list of
files and directories one-level deep.
After you receive the listing file, you can provide the files that you
want to transfer to the RetrieveFilePaths parameter of the
StartFileTransfer API call.
The naming convention for the output file is connector-ID-listing-ID.json. The output file contains the following
information:
-
filePath: the complete path of a remote file, relative to the directory of the listing request for your SFTP connector on the remote server. -
modifiedTimestamp: the last time the file was modified, in UTC time format. This field is optional. If the remote file attributes don't contain a timestamp, it is omitted from the file listing. -
size: the size of the file, in bytes. This field is optional. If the remote file attributes don't contain a file size, it is omitted from the file listing. -
path: the complete path of a remote directory, relative to the directory of the listing request for your SFTP connector on the remote server. -
truncated: a flag indicating whether the list output contains all of the items contained in the remote directory or not. If yourTruncatedoutput value is true, you can increase the value provided in the optionalmax-itemsinput attribute to be able to list more items (up to the maximum allowed list size of 200,000 items).
800 |
# File 'sig/client.rbs', line 800
def start_directory_listing: (
|
#start_file_transfer(params = {}) ⇒ Types::StartFileTransferResponse
Begins a file transfer between local Amazon Web Services storage and a remote AS2 or SFTP server.
-
For an AS2 connector, you specify the
ConnectorIdand one or moreSendFilePathsto identify the files you want to transfer. -
For an SFTP connector, the file transfer can be either outbound or inbound. In both cases, you specify the
ConnectorId. Depending on the direction of the transfer, you also specify the following items: -
If you are transferring file from a partner's SFTP server to Amazon Web Services storage, you specify one or more
RetrieveFilePathsto identify the files you want to transfer, and aLocalDirectoryPathto specify the destination folder. -
If you are transferring file to a partner's SFTP server from Amazon Web Services storage, you specify one or more
SendFilePathsto identify the files you want to transfer, and aRemoteDirectoryPathto specify the destination folder.
813 |
# File 'sig/client.rbs', line 813
def start_file_transfer: (
|
#start_remote_delete(params = {}) ⇒ Types::StartRemoteDeleteResponse
Deletes a file or directory on the remote SFTP server.
833 |
# File 'sig/client.rbs', line 833
def start_remote_delete: (
|
#start_remote_move(params = {}) ⇒ Types::StartRemoteMoveResponse
Moves or renames a file or directory on the remote SFTP server.
844 |
# File 'sig/client.rbs', line 844
def start_remote_move: (
|
#start_server(params = {}) ⇒ Struct
Changes the state of a file transfer protocol-enabled server from
OFFLINE to ONLINE. It has no impact on a server that is already
ONLINE. An ONLINE server can accept and process file transfer
jobs.
The state of STARTING indicates that the server is in an
intermediate state, either not fully able to respond, or not fully
online. The values of START_FAILED can indicate an error condition.
No response is returned from this call.
852 |
# File 'sig/client.rbs', line 852
def start_server: (
|
#stop_server(params = {}) ⇒ Struct
Changes the state of a file transfer protocol-enabled server from
ONLINE to OFFLINE. An OFFLINE server cannot accept and process
file transfer jobs. Information tied to your server, such as server
and user properties, are not affected by stopping your server.
The state of STOPPING indicates that the server is in an
intermediate state, either not fully able to respond, or not fully
offline. The values of STOP_FAILED can indicate an error condition.
No response is returned from this call.
858 |
# File 'sig/client.rbs', line 858
def stop_server: (
|
#tag_resource(params = {}) ⇒ Struct
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
There is no response returned from this call.
864 |
# File 'sig/client.rbs', line 864
def tag_resource: (
|
#test_connection(params = {}) ⇒ Types::TestConnectionResponse
Tests whether your SFTP connector is set up successfully. We highly recommend that you call this operation to test your ability to transfer files between local Amazon Web Services storage and a trading partner's SFTP server.
883 |
# File 'sig/client.rbs', line 883
def test_connection: (
|
#test_identity_provider(params = {}) ⇒ Types::TestIdentityProviderResponse
If the IdentityProviderType of a file transfer protocol-enabled
server is AWS_DIRECTORY_SERVICE or API_Gateway, tests whether your
identity provider is set up successfully. We highly recommend that you
call this operation to test your authentication method as soon as you
create your server. By doing so, you can troubleshoot issues with the
identity provider integration to ensure that your users can
successfully use the service.
The ServerId and UserName parameters are required. The
ServerProtocol, SourceIp, and UserPassword are all optional.
Note the following:
-
You cannot use
TestIdentityProviderif theIdentityProviderTypeof your server isSERVICE_MANAGED. -
TestIdentityProviderdoes not work with keys: it only accepts passwords. -
TestIdentityProvidercan test the password operation for a custom Identity Provider that handles keys and passwords. -
If you provide any incorrect values for any parameters, the
Responsefield is empty. -
If you provide a server ID for a server that uses service-managed users, you get an error:
An error occurred (InvalidRequestException) when calling the TestIdentityProvider operation: s-server-ID not configured for external auth -
If you enter a Server ID for the
--server-idparameter that does not identify an actual Transfer server, you receive the following error:An error occurred (ResourceNotFoundException) when calling the TestIdentityProvider operation: Unknown server.It is possible your sever is in a different region. You can specify a region by adding the following:
--region region-code, such as--region us-east-2to specify a server in US East (Ohio).
896 |
# File 'sig/client.rbs', line 896
def test_identity_provider: (
|
#untag_resource(params = {}) ⇒ Struct
Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
No response is returned from this call.
906 |
# File 'sig/client.rbs', line 906
def untag_resource: (
|
#update_access(params = {}) ⇒ Types::UpdateAccessResponse
Allows you to update parameters for the access specified in the
ServerID and ExternalID parameters.
918 |
# File 'sig/client.rbs', line 918
def update_access: (
|
#update_agreement(params = {}) ⇒ Types::UpdateAgreementResponse
Updates some of the parameters for an existing agreement. Provide the
AgreementId and the ServerId for the agreement that you want to
update, along with the new values for the parameters to update.
BaseDirectory or CustomDirectories, but not both.
Specifying both causes the command to fail.
If you update an agreement from using base directory to custom directories, the base directory is no longer used. Similarly, if you change from custom directories to a base directory, the custom directories are no longer used.
945 |
# File 'sig/client.rbs', line 945
def update_agreement: (
|
#update_certificate(params = {}) ⇒ Types::UpdateCertificateResponse
Updates the active and inactive dates for a certificate.
971 |
# File 'sig/client.rbs', line 971
def update_certificate: (
|
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates some of the parameters for an existing connector. Provide the
ConnectorId for the connector that you want to update, along with
the new values for the parameters to update.
984 |
# File 'sig/client.rbs', line 984
def update_connector: (
|
#update_host_key(params = {}) ⇒ Types::UpdateHostKeyResponse
Updates the description for the host key that's specified by the
ServerId and HostKeyId parameters.
1013 |
# File 'sig/client.rbs', line 1013
def update_host_key: (
|
#update_profile(params = {}) ⇒ Types::UpdateProfileResponse
Updates some of the parameters for an existing profile. Provide the
ProfileId for the profile that you want to update, along with the
new values for the parameters to update.
1025 |
# File 'sig/client.rbs', line 1025
def update_profile: (
|
#update_server(params = {}) ⇒ Types::UpdateServerResponse
Updates the file transfer protocol-enabled server's properties after that server has been created.
The UpdateServer call returns the ServerId of the server you
updated.
1036 |
# File 'sig/client.rbs', line 1036
def update_server: (
|
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Assigns new properties to a user. Parameters you pass modify any or
all of the following: the home directory, role, and policy for the
UserName and ServerId you specify.
The response returns the ServerId and the UserName for the updated
user.
In the console, you can select Restricted when you create or update
a user. This ensures that the user can't access anything outside of
their home directory. The programmatic way to configure this behavior
is to update the user. Set their HomeDirectoryType to LOGICAL, and
specify HomeDirectoryMappings with Entry as root (/) and
Target as their home directory.
For example, if the user's home directory is /test/admin-user, the
following command updates the user so that their configuration in the
console shows the Restricted flag as selected.
aws transfer update-user --server-id <server-id> --user-name admin-user --home-directory-type LOGICAL --home-directory-mappings "[{"Entry":"/", "Target":"/test/admin-user"}]"
1077 |
# File 'sig/client.rbs', line 1077
def update_user: (
|
#update_web_app(params = {}) ⇒ Types::UpdateWebAppResponse
Assigns new properties to a web app. You can modify the access point, identity provider details, endpoint configuration, and the web app units.
For more information about using VPC endpoints with Transfer Family, see Create a Transfer Family web app in a VPC.
1104 |
# File 'sig/client.rbs', line 1104
def update_web_app: (
|
#update_web_app_customization(params = {}) ⇒ Types::UpdateWebAppCustomizationResponse
Assigns new customization properties to a web app. You can modify the icon file, logo file, and title.
1129 |
# File 'sig/client.rbs', line 1129
def update_web_app_customization: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| server_offline | #describe_server | 30 | 120 |
| server_online | #describe_server | 30 | 120 |
1138 |
# File 'sig/client.rbs', line 1138
def wait_until: (:server_offline waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5884 5885 5886 |
# File 'lib/aws-sdk-transfer/client.rb', line 5884 def waiter_names waiters.keys end |