Method: Aws::Transfer::Client#create_access

Defined in:
lib/aws-sdk-transfer/client.rb

#create_access(params = {}) ⇒ Types::CreateAccessResponse

Used by administrators to choose which groups in the directory should have access to upload and download files over the enabled protocols using Transfer Family. For example, a Microsoft Active Directory might contain 50,000 users, but only a small fraction might need the ability to transfer files to the server. An administrator can use CreateAccess to limit the access to the correct set of users who need this ability.

Examples:

Request syntax with placeholder values


resp = client.create_access({
  home_directory: "HomeDirectory",
  home_directory_type: "PATH", # accepts PATH, LOGICAL
  home_directory_mappings: [
    {
      entry: "MapEntry", # required
      target: "MapTarget", # required
      type: "FILE", # accepts FILE, DIRECTORY
    },
  ],
  policy: "Policy",
  posix_profile: {
    uid: 1, # required
    gid: 1, # required
    secondary_gids: [1],
  },
  role: "Role", # required
  server_id: "ServerId", # required
  external_id: "ExternalId", # required
})

Response structure


resp.server_id #=> String
resp.external_id #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :home_directory (String)

    The landing directory (folder) for a user when they log in to the server using the client.

    A HomeDirectory example is /bucket_name/home/mydirectory.

    <note markdown=“1”> The HomeDirectory parameter is only used if HomeDirectoryType is set to PATH.

    </note>
    
  • :home_directory_type (String)

    The type of landing directory (folder) that you want your users’ home directory to be when they log in to the server. If you set it to PATH, the user will see the absolute Amazon S3 bucket or Amazon EFS path as is in their file transfer protocol clients. If you set it to LOGICAL, you need to provide mappings in the HomeDirectoryMappings for how you want to make Amazon S3 or Amazon EFS paths visible to your users.

    <note markdown=“1”> If HomeDirectoryType is LOGICAL, you must provide mappings, using the HomeDirectoryMappings parameter. If, on the other hand, HomeDirectoryType is PATH, you provide an absolute path using the HomeDirectory parameter. You cannot have both HomeDirectory and HomeDirectoryMappings in your template.

    </note>
    
  • :home_directory_mappings (Array<Types::HomeDirectoryMapEntry>)

    Logical directory mappings that specify what Amazon S3 or Amazon EFS paths and keys should be visible to your user and how you want to make them visible. You must specify the Entry and Target pair, where Entry shows how the path is made visible and Target is the actual Amazon S3 or Amazon EFS path. If you only specify a target, it is displayed as is. You also must ensure that your Identity and Access Management (IAM) role provides access to paths in Target. This value can be set only when HomeDirectoryType is set to LOGICAL.

    The following is an Entry and Target pair example.

    ‘[ { “Entry”: “/directory1”, “Target”: “/bucket_name/home/mydirectory” } ]`

    In most cases, you can use this value instead of the session policy to lock down your user to the designated home directory (“chroot”). To do this, you can set Entry to / and set Target to the HomeDirectory parameter value.

    The following is an Entry and Target pair example for chroot.

    ‘[ { “Entry”: “/”, “Target”: “/bucket_name/home/mydirectory” } ]`

  • :policy (String)

    A session policy for your user so that you can use the same Identity and Access Management (IAM) role across multiple users. This policy scopes down a user’s access to portions of their Amazon S3 bucket. Variables that you can use inside this policy include ‘$Transfer:UserName`, `$Transfer:HomeDirectory`, and `$Transfer:HomeBucket`.

    <note markdown=“1”> This policy applies only when the domain of ServerId is Amazon S3. Amazon EFS does not use session policies.

    For session policies, Transfer Family stores the policy as a JSON
    

    blob, instead of the Amazon Resource Name (ARN) of the policy. You save the policy as a JSON blob and pass it in the Policy argument.

    For an example of a session policy, see [Example session policy][1].
    
    For more information, see [AssumeRole][2] in the *Security Token
    

    Service API Reference*.

    </note>
    

    [1]: docs.aws.amazon.com/transfer/latest/userguide/session-policy.html [2]: docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRole.html

  • :posix_profile (Types::PosixProfile)

    The full POSIX identity, including user ID (Uid), group ID (Gid), and any secondary groups IDs (SecondaryGids), that controls your users’ access to your Amazon EFS file systems. The POSIX permissions that are set on files and directories in your file system determine the level of access your users get when transferring files into and out of your Amazon EFS file systems.

  • :role (required, String)

    The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that controls your users’ access to your Amazon S3 bucket or Amazon EFS file system. The policies attached to this role determine the level of access that you want to provide your users when transferring files into and out of your Amazon S3 bucket or Amazon EFS file system. The IAM role should also contain a trust relationship that allows the server to access your resources when servicing your users’ transfer requests.

  • :server_id (required, String)

    A system-assigned unique identifier for a server instance. This is the specific server that you added your user to.

  • :external_id (required, String)

    A unique identifier that is required to identify specific groups within your directory. The users of the group that you associate have access to your Amazon S3 or Amazon EFS resources over the enabled protocols using Transfer Family. If you know the group name, you can view the SID values by running the following command using Windows PowerShell.

    ‘Get-ADGroup -Filter -like “YourGroupName*” -Properties * | Select SamAccountName,ObjectSid`

    In that command, replace YourGroupName with the name of your Active Directory group.

    The regular expression used to validate this parameter is a string of characters consisting of uppercase and lowercase alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@:/-

Returns:

See Also:



622
623
624
625
# File 'lib/aws-sdk-transfer/client.rb', line 622

def create_access(params = {}, options = {})
  req = build_request(:create_access, params)
  req.send_request(options)
end