Class: Aws::Transfer::Types::As2AsyncMdnConnectorConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Contains the configuration details for asynchronous Message Disposition Notification (MDN) responses in AS2 connectors. This configuration specifies where asynchronous MDN responses should be sent and which servers should handle them.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#server_idsArray<String>

A list of server identifiers that can handle asynchronous MDN responses. You can specify between 1 and 10 server IDs.

Returns:

  • (Array<String>)


42
43
44
45
46
47
# File 'lib/aws-sdk-transfer/types.rb', line 42

class As2AsyncMdnConnectorConfig < Struct.new(
  :url,
  :server_ids)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The URL endpoint where asynchronous MDN responses should be sent.

Returns:

  • (String)


42
43
44
45
46
47
# File 'lib/aws-sdk-transfer/types.rb', line 42

class As2AsyncMdnConnectorConfig < Struct.new(
  :url,
  :server_ids)
  SENSITIVE = []
  include Aws::Structure
end