Class: Aws::Transfer::Types::As2ConnectorConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Contains the details for an AS2 connector object. The connector object is used for AS2 outbound processes, to connect the Transfer Family customer with the trading partner.

Constant Summary collapse

SENSITIVE =
[:message_subject]

Instance Attribute Summary collapse

Instance Attribute Details

#async_mdn_configTypes::As2AsyncMdnConnectorConfig

Configuration settings for asynchronous Message Disposition Notification (MDN) responses. This allows you to configure where asynchronous MDN responses should be sent and which servers should handle them.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#basic_auth_secret_idString

Provides Basic authentication support to the AS2 Connectors API. To use Basic authentication, you must provide the name or Amazon Resource Name (ARN) of a secret in Secrets Manager.

The default value for this parameter is null, which indicates that Basic authentication is not enabled for the connector.

If the connector should use Basic authentication, the secret needs to be in the following format:

‘{ “Username”: “user-name”, “Password”: “user-password” }`

Replace user-name and user-password with the credentials for the actual user that is being authenticated.

Note the following:

  • You are storing these credentials in Secrets Manager, *not passing them directly* into this API.

  • If you are using the API, SDKs, or CloudFormation to configure your connector, then you must create the secret before you can enable Basic authentication. However, if you are using the Amazon Web Services management console, you can have the system create the secret for you.

If you have previously enabled Basic authentication for a connector, you can disable it by using the UpdateConnector API call. For example, if you are using the CLI, you can run the following command to remove Basic authentication:

‘update-connector –connector-id my-connector-id –as2-config ’BasicAuthSecretId=“”‘`

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#compressionString

Specifies whether the AS2 file is compressed.

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#encryption_algorithmString

The algorithm that is used to encrypt the file.

Note the following:

  • Do not use the DES_EDE3_CBC algorithm unless you must support a legacy client that requires it, as it is a weak encryption algorithm.

  • You can only specify NONE if the URL for your connector uses HTTPS. Using HTTPS ensures that no traffic is sent in clear text.

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#local_profile_idString

A unique identifier for the AS2 local profile.

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#mdn_responseString

Used for outbound requests (from an Transfer Family connector to a partner AS2 server) to determine whether the partner response for transfers is synchronous or asynchronous. Specify either of the following values:

  • ASYNC: The system expects an asynchronous MDN response, confirming that the file was transferred successfully (or not).

  • SYNC: The system expects a synchronous MDN response, confirming that the file was transferred successfully (or not).

  • NONE: Specifies that no MDN response is required.

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#mdn_signing_algorithmString

The signing algorithm for the MDN response.

<note markdown=“1”> If set to DEFAULT (or not set at all), the value for SigningAlgorithm is used.

</note>

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#message_subjectString

Used as the Subject HTTP header attribute in AS2 messages that are being sent with the connector.

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#partner_profile_idString

A unique identifier for the partner profile for the connector.

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#preserve_content_typeString

Allows you to use the Amazon S3 Content-Type that is associated with objects in S3 instead of having the content type mapped based on the file extension. This parameter is enabled by default when you create an AS2 connector from the console, but disabled by default when you create an AS2 connector by calling the API directly.

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end

#signing_algorithmString

The algorithm that is used to sign the AS2 messages sent with the connector.

Returns:

  • (String)


165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/aws-sdk-transfer/types.rb', line 165

class As2ConnectorConfig < Struct.new(
  :local_profile_id,
  :partner_profile_id,
  :message_subject,
  :compression,
  :encryption_algorithm,
  :signing_algorithm,
  :mdn_signing_algorithm,
  :mdn_response,
  :basic_auth_secret_id,
  :preserve_content_type,
  :async_mdn_config)
  SENSITIVE = [:message_subject]
  include Aws::Structure
end