Class: Aws::Transfer::Types::ConnectorEgressConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Note:

ConnectorEgressConfig is a union - when making an API calls you must set exactly one of the members.

Configuration structure that defines how traffic is routed from the connector to the SFTP server. Contains VPC Lattice settings when using VPC_LATTICE egress type for private connectivity through customer VPCs.

Direct Known Subclasses

Unknown, VpcLattice

Defined Under Namespace

Classes: Unknown, VpcLattice

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unknownObject

Returns the value of attribute unknown



211
212
213
# File 'lib/aws-sdk-transfer/types.rb', line 211

def unknown
  @unknown
end

#vpc_latticeTypes::ConnectorVpcLatticeEgressConfig

VPC_LATTICE configuration for routing connector traffic through customer VPCs. Enables private connectivity to SFTP servers without requiring public internet access or complex network configurations.



211
212
213
214
215
216
217
218
219
220
# File 'lib/aws-sdk-transfer/types.rb', line 211

class ConnectorEgressConfig < Struct.new(
  :vpc_lattice,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class VpcLattice < ConnectorEgressConfig; end
  class Unknown < ConnectorEgressConfig; end
end