Class: Aws::Transfer::Types::CopyStepDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::CopyStepDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Each step type has its own StepDetails structure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_file_location ⇒ Types::InputFileLocation
Specifies the location for the file being copied.
-
#name ⇒ String
The name of the step, used as an identifier.
-
#overwrite_existing ⇒ String
A flag that indicates whether to overwrite an existing file of the same name.
-
#source_file_location ⇒ String
Specifies which file to use as input to the workflow step: either the output from the previous step, or the originally uploaded file for the workflow.
Instance Attribute Details
#destination_file_location ⇒ Types::InputFileLocation
Specifies the location for the file being copied. Use
${Transfer:UserName} or ${Transfer:UploadDate} in this field to
parametrize the destination prefix by username or uploaded date.
-
Set the value of
DestinationFileLocationto${Transfer:UserName}to copy uploaded files to an Amazon S3 bucket that is prefixed with the name of the Transfer Family user that uploaded the file. -
Set the value of
DestinationFileLocationto${Transfer:UploadDate}to copy uploaded files to an Amazon S3 bucket that is prefixed with the date of the upload.The system resolves UploadDateto a date format of YYYY-MM-DD, based on the date the file is uploaded in UTC.
337 338 339 340 341 342 343 344 |
# File 'lib/aws-sdk-transfer/types.rb', line 337 class CopyStepDetails < Struct.new( :name, :destination_file_location, :overwrite_existing, :source_file_location) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the step, used as an identifier.
337 338 339 340 341 342 343 344 |
# File 'lib/aws-sdk-transfer/types.rb', line 337 class CopyStepDetails < Struct.new( :name, :destination_file_location, :overwrite_existing, :source_file_location) SENSITIVE = [] include Aws::Structure end |
#overwrite_existing ⇒ String
A flag that indicates whether to overwrite an existing file of the
same name. The default is FALSE.
If the workflow is processing a file that has the same name as an existing file, the behavior is as follows:
-
If
OverwriteExistingisTRUE, the existing file is replaced with the file being processed. -
If
OverwriteExistingisFALSE, nothing happens, and the workflow processing stops.
337 338 339 340 341 342 343 344 |
# File 'lib/aws-sdk-transfer/types.rb', line 337 class CopyStepDetails < Struct.new( :name, :destination_file_location, :overwrite_existing, :source_file_location) SENSITIVE = [] include Aws::Structure end |
#source_file_location ⇒ String
Specifies which file to use as input to the workflow step: either the output from the previous step, or the originally uploaded file for the workflow.
-
To use the previous file as the input, enter
${previous.file}. In this case, this workflow step uses the output file from the previous workflow step as input. This is the default value. -
To use the originally uploaded file location as input for this step, enter
${original.file}.
337 338 339 340 341 342 343 344 |
# File 'lib/aws-sdk-transfer/types.rb', line 337 class CopyStepDetails < Struct.new( :name, :destination_file_location, :overwrite_existing, :source_file_location) SENSITIVE = [] include Aws::Structure end |