Class: Aws::Transfer::Types::CreateConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::CreateConnectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_role ⇒ String
Connectors are used to send files using either the AS2 or SFTP protocol.
-
#as_2_config ⇒ Types::As2ConnectorConfig
A structure that contains the parameters for an AS2 connector object.
-
#egress_config ⇒ Types::ConnectorEgressConfig
Specifies the egress configuration for the connector, which determines how traffic is routed from the connector to the SFTP server.
-
#ip_address_type ⇒ String
Specifies the IP address type for the connector's network connections.
-
#logging_role ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that allows a connector to turn on CloudWatch logging for Amazon S3 events.
-
#security_policy_name ⇒ String
Specifies the name of the security policy for the connector.
-
#sftp_config ⇒ Types::SftpConnectorConfig
A structure that contains the parameters for an SFTP connector object.
-
#tags ⇒ Array<Types::Tag>
Key-value pairs that can be used to group and search for connectors.
-
#url ⇒ String
The URL of the partner's AS2 or SFTP endpoint.
Instance Attribute Details
#access_role ⇒ String
Connectors are used to send files using either the AS2 or SFTP protocol. For the access role, provide the Amazon Resource Name (ARN) of the Identity and Access Management role to use.
For AS2 connectors
With AS2, you can send files by calling StartFileTransfer and
specifying the file paths in the request parameter, SendFilePaths.
We use the file’s parent directory (for example, for
--send-file-paths /bucket/dir/file.txt, parent directory is
/bucket/dir/) to temporarily store a processed AS2 message file,
store the MDN when we receive them from the partner, and write a
final JSON file containing relevant metadata of the transmission.
So, the AccessRole needs to provide read and write access to the
parent directory of the file location used in the
StartFileTransfer request. Additionally, you need to provide read
and write access to the parent directory of the files that you
intend to send with StartFileTransfer.
If you are using Basic authentication for your AS2 connector, the
access role requires the secretsmanager:GetSecretValue permission
for the secret. If the secret is encrypted using a customer-managed
key instead of the Amazon Web Services managed key in Secrets
Manager, then the role also needs the kms:Decrypt permission for
that key.
For SFTP connectors
Make sure that the access role provides read and write access to the
parent directory of the file location that's used in the
StartFileTransfer request. Additionally, make sure that the role
provides secretsmanager:GetSecretValue permission to Secrets
Manager.
742 743 744 745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-transfer/types.rb', line 742 class CreateConnectorRequest < Struct.new( :url, :as_2_config, :access_role, :logging_role, :tags, :sftp_config, :security_policy_name, :egress_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#as_2_config ⇒ Types::As2ConnectorConfig
A structure that contains the parameters for an AS2 connector object.
742 743 744 745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-transfer/types.rb', line 742 class CreateConnectorRequest < Struct.new( :url, :as_2_config, :access_role, :logging_role, :tags, :sftp_config, :security_policy_name, :egress_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#egress_config ⇒ Types::ConnectorEgressConfig
Specifies the egress configuration for the connector, which determines how traffic is routed from the connector to the SFTP server. When set to VPC, enables routing through customer VPCs using VPC_LATTICE for private connectivity.
742 743 744 745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-transfer/types.rb', line 742 class CreateConnectorRequest < Struct.new( :url, :as_2_config, :access_role, :logging_role, :tags, :sftp_config, :security_policy_name, :egress_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
Specifies the IP address type for the connector's network
connections. When set to IPV4, the connector uses IPv4 addresses
only. When set to DUALSTACK, the connector supports both IPv4 and
IPv6 addresses, with IPv6 preferred when available.
742 743 744 745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-transfer/types.rb', line 742 class CreateConnectorRequest < Struct.new( :url, :as_2_config, :access_role, :logging_role, :tags, :sftp_config, :security_policy_name, :egress_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#logging_role ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that allows a connector to turn on CloudWatch logging for Amazon S3 events. When set, you can view connector activity in your CloudWatch logs.
742 743 744 745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-transfer/types.rb', line 742 class CreateConnectorRequest < Struct.new( :url, :as_2_config, :access_role, :logging_role, :tags, :sftp_config, :security_policy_name, :egress_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#security_policy_name ⇒ String
Specifies the name of the security policy for the connector.
742 743 744 745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-transfer/types.rb', line 742 class CreateConnectorRequest < Struct.new( :url, :as_2_config, :access_role, :logging_role, :tags, :sftp_config, :security_policy_name, :egress_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#sftp_config ⇒ Types::SftpConnectorConfig
A structure that contains the parameters for an SFTP connector object.
742 743 744 745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-transfer/types.rb', line 742 class CreateConnectorRequest < Struct.new( :url, :as_2_config, :access_role, :logging_role, :tags, :sftp_config, :security_policy_name, :egress_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Key-value pairs that can be used to group and search for connectors. Tags are metadata attached to connectors for any purpose.
742 743 744 745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-transfer/types.rb', line 742 class CreateConnectorRequest < Struct.new( :url, :as_2_config, :access_role, :logging_role, :tags, :sftp_config, :security_policy_name, :egress_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL of the partner's AS2 or SFTP endpoint.
When creating AS2 connectors or service-managed SFTP connectors (connectors without egress configuration), you must provide a URL to specify the remote server endpoint. For VPC Lattice type connectors, the URL must be null.
742 743 744 745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-transfer/types.rb', line 742 class CreateConnectorRequest < Struct.new( :url, :as_2_config, :access_role, :logging_role, :tags, :sftp_config, :security_policy_name, :egress_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |