Class: Aws::Transfer::Types::CreateWorkflowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A textual description for the workflow.

Returns:

  • (String)


1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-transfer/types.rb', line 1495

class CreateWorkflowRequest < Struct.new(
  :description,
  :steps,
  :on_exception_steps,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#on_exception_stepsArray<Types::WorkflowStep>

Specifies the steps (actions) to take if errors are encountered during execution of the workflow.

<note markdown=“1”> For custom steps, the Lambda function needs to send FAILURE to the call back API to kick off the exception steps. Additionally, if the Lambda does not send SUCCESS before it times out, the exception steps are executed.

</note>

Returns:



1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-transfer/types.rb', line 1495

class CreateWorkflowRequest < Struct.new(
  :description,
  :steps,
  :on_exception_steps,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stepsArray<Types::WorkflowStep>

Specifies the details for the steps that are in the specified workflow.

The TYPE specifies which of the following actions is being taken for this step.

  • COPY - Copy the file to another location.

  • CUSTOM - Perform a custom step with an Lambda function target.

  • DECRYPT - Decrypt a file that was encrypted before it was uploaded.

  • DELETE - Delete the file.

  • TAG - Add a tag to the file.

<note markdown=“1”> Currently, copying and tagging are supported only on S3.

</note>

For file location, you specify either the Amazon S3 bucket and key, or the Amazon EFS file system ID and path.

Returns:



1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-transfer/types.rb', line 1495

class CreateWorkflowRequest < Struct.new(
  :description,
  :steps,
  :on_exception_steps,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Key-value pairs that can be used to group and search for workflows. Tags are metadata attached to workflows for any purpose.

Returns:



1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-transfer/types.rb', line 1495

class CreateWorkflowRequest < Struct.new(
  :description,
  :steps,
  :on_exception_steps,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end