Class: Aws::Transfer::Types::DescribeSecurityPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::DescribeSecurityPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_policy_name ⇒ String
Specify the text name of the security policy for which you want the details.
Instance Attribute Details
#security_policy_name ⇒ String
Specify the text name of the security policy for which you want the details.
1851 1852 1853 1854 1855 |
# File 'lib/aws-sdk-transfer/types.rb', line 1851 class DescribeSecurityPolicyRequest < Struct.new( :security_policy_name) SENSITIVE = [] include Aws::Structure end |