Class: Aws::Transfer::Types::DescribedConnectorEgressConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::DescribedConnectorEgressConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
DescribedConnectorEgressConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of DescribedConnectorEgressConfig corresponding to the set member.
Response structure containing the current egress configuration details for the connector. Shows how traffic is currently routed from the connector to the SFTP server.
Direct Known Subclasses
Defined Under Namespace
Classes: Unknown, VpcLattice
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#vpc_lattice ⇒ Types::DescribedConnectorVpcLatticeEgressConfig
VPC_LATTICE configuration details in the response, showing the current Resource Configuration ARN and port settings for VPC-based connectivity.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
2794 2795 2796 |
# File 'lib/aws-sdk-transfer/types.rb', line 2794 def unknown @unknown end |
#vpc_lattice ⇒ Types::DescribedConnectorVpcLatticeEgressConfig
VPC_LATTICE configuration details in the response, showing the current Resource Configuration ARN and port settings for VPC-based connectivity.
2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 |
# File 'lib/aws-sdk-transfer/types.rb', line 2794 class DescribedConnectorEgressConfig < Struct.new( :vpc_lattice, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class VpcLattice < DescribedConnectorEgressConfig; end class Unknown < DescribedConnectorEgressConfig; end end |