Class: Aws::Transfer::Types::DescribedWebApp

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

A structure that describes the parameters for the web app, as identified by the WebAppId.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_endpointString

The AccessEndpoint is the URL that you provide to your users for them to interact with the Transfer Family web app. You can specify a custom URL or use the default value.



3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-transfer/types.rb', line 3112

class DescribedWebApp < Struct.new(
  :arn,
  :web_app_id,
  :described_identity_provider_details,
  :access_endpoint,
  :web_app_endpoint,
  :web_app_units,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the web app.



3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-transfer/types.rb', line 3112

class DescribedWebApp < Struct.new(
  :arn,
  :web_app_id,
  :described_identity_provider_details,
  :access_endpoint,
  :web_app_endpoint,
  :web_app_units,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#described_identity_provider_detailsTypes::DescribedWebAppIdentityProviderDetails

A structure that contains the details for the identity provider used by the web app.



3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-transfer/types.rb', line 3112

class DescribedWebApp < Struct.new(
  :arn,
  :web_app_id,
  :described_identity_provider_details,
  :access_endpoint,
  :web_app_endpoint,
  :web_app_units,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Key-value pairs that can be used to group and search for web apps. Tags are metadata attached to web apps for any purpose.



3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-transfer/types.rb', line 3112

class DescribedWebApp < Struct.new(
  :arn,
  :web_app_id,
  :described_identity_provider_details,
  :access_endpoint,
  :web_app_endpoint,
  :web_app_units,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#web_app_endpointString

The WebAppEndpoint is the unique URL for your Transfer Family web app. This is the value that you use when you configure Origins on CloudFront.



3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-transfer/types.rb', line 3112

class DescribedWebApp < Struct.new(
  :arn,
  :web_app_id,
  :described_identity_provider_details,
  :access_endpoint,
  :web_app_endpoint,
  :web_app_units,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#web_app_idString

The unique identifier for the web app.



3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-transfer/types.rb', line 3112

class DescribedWebApp < Struct.new(
  :arn,
  :web_app_id,
  :described_identity_provider_details,
  :access_endpoint,
  :web_app_endpoint,
  :web_app_units,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#web_app_unitsTypes::WebAppUnits

A union that contains the value for number of concurrent connections or the user sessions on your web app.



3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-transfer/types.rb', line 3112

class DescribedWebApp < Struct.new(
  :arn,
  :web_app_id,
  :described_identity_provider_details,
  :access_endpoint,
  :web_app_endpoint,
  :web_app_units,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end