Class: Aws::Transfer::Types::EfsFileLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Specifies the details for the file location for the file that’s being used in the workflow. Only applicable if you are using Amazon Elastic File Systems (Amazon EFS) for storage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#file_system_idString

The identifier of the file system, assigned by Amazon EFS.

Returns:

  • (String)


3240
3241
3242
3243
3244
3245
# File 'lib/aws-sdk-transfer/types.rb', line 3240

class EfsFileLocation < Struct.new(
  :file_system_id,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The pathname for the folder being used by a workflow.

Returns:

  • (String)


3240
3241
3242
3243
3244
3245
# File 'lib/aws-sdk-transfer/types.rb', line 3240

class EfsFileLocation < Struct.new(
  :file_system_id,
  :path)
  SENSITIVE = []
  include Aws::Structure
end