Class: Aws::Transfer::Types::ListCertificatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::ListCertificatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return.
-
#next_token ⇒ String
When you can get additional results from the
ListCertificatescall, aNextTokenparameter is returned in the output.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return.
4562 4563 4564 4565 4566 4567 |
# File 'lib/aws-sdk-transfer/types.rb', line 4562 class ListCertificatesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When you can get additional results from the ListCertificates
call, a NextToken parameter is returned in the output. You can
then pass in a subsequent command to the NextToken parameter to
continue listing additional certificates.
4562 4563 4564 4565 4566 4567 |
# File 'lib/aws-sdk-transfer/types.rb', line 4562 class ListCertificatesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |