Class: Aws::Transfer::Types::ListFileTransferResultsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connector_idString

A unique identifier for a connector. This value should match the value supplied to the corresponding StartFileTransfer call.

Returns:



4722
4723
4724
4725
4726
4727
4728
4729
# File 'lib/aws-sdk-transfer/types.rb', line 4722

class ListFileTransferResultsRequest < Struct.new(
  :connector_id,
  :transfer_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of files to return in a single page. Note that currently you can specify a maximum of 10 file paths in a single StartFileTransfer operation. Thus, the maximum number of file transfer results that can be returned in a single page is 10.

Returns:



4722
4723
4724
4725
4726
4727
4728
4729
# File 'lib/aws-sdk-transfer/types.rb', line 4722

class ListFileTransferResultsRequest < Struct.new(
  :connector_id,
  :transfer_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are more file details than returned in this call, use this value for a subsequent call to ListFileTransferResults to retrieve them.

Returns:



4722
4723
4724
4725
4726
4727
4728
4729
# File 'lib/aws-sdk-transfer/types.rb', line 4722

class ListFileTransferResultsRequest < Struct.new(
  :connector_id,
  :transfer_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#transfer_idString

A unique identifier for a file transfer. This value should match the value supplied to the corresponding StartFileTransfer call.

Returns:



4722
4723
4724
4725
4726
4727
4728
4729
# File 'lib/aws-sdk-transfer/types.rb', line 4722

class ListFileTransferResultsRequest < Struct.new(
  :connector_id,
  :transfer_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end