Class: Aws::Transfer::Types::ListUsersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::ListUsersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specifies the number of users to return as a response to the
ListUsersrequest. -
#next_token ⇒ String
If there are additional results from the
ListUserscall, aNextTokenparameter is returned in the output. -
#server_id ⇒ String
A system-assigned unique identifier for a server that has users assigned to it.
Instance Attribute Details
#max_results ⇒ Integer
Specifies the number of users to return as a response to the
ListUsers request.
5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-transfer/types.rb', line 5013 class ListUsersRequest < Struct.new( :max_results, :next_token, :server_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results from the ListUsers call, a
NextToken parameter is returned in the output. You can then pass
the NextToken to a subsequent ListUsers command, to continue
listing additional users.
5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-transfer/types.rb', line 5013 class ListUsersRequest < Struct.new( :max_results, :next_token, :server_id) SENSITIVE = [] include Aws::Structure end |
#server_id ⇒ String
A system-assigned unique identifier for a server that has users assigned to it.
5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-transfer/types.rb', line 5013 class ListUsersRequest < Struct.new( :max_results, :next_token, :server_id) SENSITIVE = [] include Aws::Structure end |