Class: Aws::Transfer::Types::ListUsersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::ListUsersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
When you can get additional results from the
ListUserscall, aNextTokenparameter is returned in the output. -
#server_id ⇒ String
A system-assigned unique identifier for a server that the users are assigned to.
-
#users ⇒ Array<Types::ListedUser>
Returns the Transfer Family users and their properties for the
ServerIdvalue that you specify.
Instance Attribute Details
#next_token ⇒ String
When you can get additional results from the ListUsers call, a
NextToken parameter is returned in the output. You can then pass
in a subsequent command to the NextToken parameter to continue
listing additional users.
5040 5041 5042 5043 5044 5045 5046 |
# File 'lib/aws-sdk-transfer/types.rb', line 5040 class ListUsersResponse < Struct.new( :next_token, :server_id, :users) SENSITIVE = [] include Aws::Structure end |
#server_id ⇒ String
A system-assigned unique identifier for a server that the users are assigned to.
5040 5041 5042 5043 5044 5045 5046 |
# File 'lib/aws-sdk-transfer/types.rb', line 5040 class ListUsersResponse < Struct.new( :next_token, :server_id, :users) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::ListedUser>
Returns the Transfer Family users and their properties for the
ServerId value that you specify.
5040 5041 5042 5043 5044 5045 5046 |
# File 'lib/aws-sdk-transfer/types.rb', line 5040 class ListUsersResponse < Struct.new( :next_token, :server_id, :users) SENSITIVE = [] include Aws::Structure end |