Class: Aws::Transfer::Types::ListWebAppsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::ListWebAppsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
Provide this value for the
NextTokenparameter in a subsequent command to continue listing additional web apps. -
#web_apps ⇒ Array<Types::ListedWebApp>
Returns, for each listed web app, a structure that contains details for the web app.
Instance Attribute Details
#next_token ⇒ String
Provide this value for the NextToken parameter in a subsequent command to continue listing additional web apps.
5063 5064 5065 5066 5067 5068 |
# File 'lib/aws-sdk-transfer/types.rb', line 5063 class ListWebAppsResponse < Struct.new( :next_token, :web_apps) SENSITIVE = [] include Aws::Structure end |
#web_apps ⇒ Array<Types::ListedWebApp>
Returns, for each listed web app, a structure that contains details for the web app.
5063 5064 5065 5066 5067 5068 |
# File 'lib/aws-sdk-transfer/types.rb', line 5063 class ListWebAppsResponse < Struct.new( :next_token, :web_apps) SENSITIVE = [] include Aws::Structure end |