Class: Aws::Transfer::Types::StartFileTransferRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:custom_http_headers]

Instance Attribute Summary collapse

Instance Attribute Details

#connector_idString

The unique identifier for the connector.



6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-transfer/types.rb', line 6327

class StartFileTransferRequest < Struct.new(
  :connector_id,
  :send_file_paths,
  :retrieve_file_paths,
  :local_directory_path,
  :remote_directory_path,
  :custom_http_headers)
  SENSITIVE = [:custom_http_headers]
  include Aws::Structure
end

#custom_http_headersArray<Types::CustomHttpHeader>

An array of key-value pairs that represent custom HTTP headers to include in AS2 messages. These headers are added to the AS2 message when sending files to your trading partner.



6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-transfer/types.rb', line 6327

class StartFileTransferRequest < Struct.new(
  :connector_id,
  :send_file_paths,
  :retrieve_file_paths,
  :local_directory_path,
  :remote_directory_path,
  :custom_http_headers)
  SENSITIVE = [:custom_http_headers]
  include Aws::Structure
end

#local_directory_pathString

For an inbound transfer, the LocaDirectoryPath specifies the destination for one or more files that are transferred from the partner’s SFTP server.



6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-transfer/types.rb', line 6327

class StartFileTransferRequest < Struct.new(
  :connector_id,
  :send_file_paths,
  :retrieve_file_paths,
  :local_directory_path,
  :remote_directory_path,
  :custom_http_headers)
  SENSITIVE = [:custom_http_headers]
  include Aws::Structure
end

#remote_directory_pathString

For an outbound transfer, the RemoteDirectoryPath specifies the destination for one or more files that are transferred to the partner’s SFTP server. If you don’t specify a RemoteDirectoryPath, the destination for transferred files is the SFTP user’s home directory.



6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-transfer/types.rb', line 6327

class StartFileTransferRequest < Struct.new(
  :connector_id,
  :send_file_paths,
  :retrieve_file_paths,
  :local_directory_path,
  :remote_directory_path,
  :custom_http_headers)
  SENSITIVE = [:custom_http_headers]
  include Aws::Structure
end

#retrieve_file_pathsArray<String>

One or more source paths for the partner’s SFTP server. Each string represents a source file path for one inbound file transfer.



6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-transfer/types.rb', line 6327

class StartFileTransferRequest < Struct.new(
  :connector_id,
  :send_file_paths,
  :retrieve_file_paths,
  :local_directory_path,
  :remote_directory_path,
  :custom_http_headers)
  SENSITIVE = [:custom_http_headers]
  include Aws::Structure
end

#send_file_pathsArray<String>

One or more source paths for the Amazon S3 storage. Each string represents a source file path for one outbound file transfer. For example, ‘ amzn-s3-demo-bucket/myfile.txt `.

<note markdown=“1”> Replace ‘ amzn-s3-demo-bucket ` with one of your actual buckets.

</note>


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-transfer/types.rb', line 6327

class StartFileTransferRequest < Struct.new(
  :connector_id,
  :send_file_paths,
  :retrieve_file_paths,
  :local_directory_path,
  :remote_directory_path,
  :custom_http_headers)
  SENSITIVE = [:custom_http_headers]
  include Aws::Structure
end