Class: Aws::Transfer::Types::StartRemoteMoveRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::StartRemoteMoveRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_id ⇒ String
The unique identifier for the connector.
-
#source_path ⇒ String
The absolute path of the file or directory to move or rename.
-
#target_path ⇒ String
The absolute path for the target of the move/rename operation.
Instance Attribute Details
#connector_id ⇒ String
The unique identifier for the connector.
6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-transfer/types.rb', line 6484 class StartRemoteMoveRequest < Struct.new( :connector_id, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |
#source_path ⇒ String
The absolute path of the file or directory to move or rename. You can only specify one path per call to this operation.
6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-transfer/types.rb', line 6484 class StartRemoteMoveRequest < Struct.new( :connector_id, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |
#target_path ⇒ String
The absolute path for the target of the move/rename operation.
6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-transfer/types.rb', line 6484 class StartRemoteMoveRequest < Struct.new( :connector_id, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |