Method: Aws::Transfer::Types::TestIdentityProviderResponse#message

Defined in:
lib/aws-sdk-transfer/types.rb

#messageString

A message that indicates whether the test was successful or not.

<note markdown=“1”> If an empty string is returned, the most likely cause is that the authentication failed due to an incorrect username or password.

</note>

Returns:

  • (String)


5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-transfer/types.rb', line 5911

class TestIdentityProviderResponse < Struct.new(
  :response,
  :status_code,
  :message,
  :url)
  SENSITIVE = []
  include Aws::Structure
end