Class: Aws::Transfer::Types::UpdateAgreementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::UpdateAgreementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_role ⇒ String
Connectors are used to send files using either the AS2 or SFTP protocol.
-
#agreement_id ⇒ String
A unique identifier for the agreement.
-
#base_directory ⇒ String
To change the landing directory (folder) for files that are transferred, provide the bucket folder that you want to use; for example, ‘/amzn-s3-demo-bucket/home/mydirectory `.
-
#custom_directories ⇒ Types::CustomDirectoriesType
A
CustomDirectoriesTypestructure. -
#description ⇒ String
To replace the existing description, provide a short description for the agreement.
-
#enforce_message_signing ⇒ String
Determines whether or not unsigned messages from your trading partners will be accepted.
-
#local_profile_id ⇒ String
A unique identifier for the AS2 local profile.
-
#partner_profile_id ⇒ String
A unique identifier for the partner profile.
-
#preserve_filename ⇒ String
Determines whether or not Transfer Family appends a unique string of characters to the end of the AS2 message payload filename when saving it.
-
#server_id ⇒ String
A system-assigned unique identifier for a server instance.
-
#status ⇒ String
You can update the status for the agreement, either activating an inactive agreement or the reverse.
Instance Attribute Details
#access_role ⇒ String
Connectors are used to send files using either the AS2 or SFTP protocol. For the access role, provide the Amazon Resource Name (ARN) of the Identity and Access Management role to use.
**For AS2 connectors**
With AS2, you can send files by calling StartFileTransfer and specifying the file paths in the request parameter, SendFilePaths. We use the file’s parent directory (for example, for ‘–send-file-paths /bucket/dir/file.txt`, parent directory is /bucket/dir/) to temporarily store a processed AS2 message file, store the MDN when we receive them from the partner, and write a final JSON file containing relevant metadata of the transmission. So, the AccessRole needs to provide read and write access to the parent directory of the file location used in the StartFileTransfer request. Additionally, you need to provide read and write access to the parent directory of the files that you intend to send with StartFileTransfer.
If you are using Basic authentication for your AS2 connector, the access role requires the secretsmanager:GetSecretValue permission for the secret. If the secret is encrypted using a customer-managed key instead of the Amazon Web Services managed key in Secrets Manager, then the role also needs the kms:Decrypt permission for that key.
**For SFTP connectors**
Make sure that the access role provides read and write access to the parent directory of the file location that’s used in the StartFileTransfer request. Additionally, make sure that the role provides secretsmanager:GetSecretValue permission to Secrets Manager.
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#agreement_id ⇒ String
A unique identifier for the agreement. This identifier is returned when you create an agreement.
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#base_directory ⇒ String
To change the landing directory (folder) for files that are transferred, provide the bucket folder that you want to use; for example, ‘/amzn-s3-demo-bucket/home/mydirectory `.
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#custom_directories ⇒ Types::CustomDirectoriesType
A CustomDirectoriesType structure. This structure specifies custom directories for storing various AS2 message files. You can specify directories for the following types of files.
-
Failed files
-
MDN files
-
Payload files
-
Status files
-
Temporary files
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
To replace the existing description, provide a short description for the agreement.
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#enforce_message_signing ⇒ String
Determines whether or not unsigned messages from your trading partners will be accepted.
-
ENABLED: Transfer Family rejects unsigned messages from your trading partner. -
DISABLED(default value): Transfer Family accepts unsigned messages from your trading partner.
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#local_profile_id ⇒ String
A unique identifier for the AS2 local profile.
To change the local profile identifier, provide a new value here.
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#partner_profile_id ⇒ String
A unique identifier for the partner profile. To change the partner profile identifier, provide a new value here.
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#preserve_filename ⇒ String
Determines whether or not Transfer Family appends a unique string of characters to the end of the AS2 message payload filename when saving it.
-
ENABLED: the filename provided by your trading parter is preserved when the file is saved. -
DISABLED(default value): when Transfer Family saves the file, the filename is adjusted, as described in [File names and locations].
[1]: docs.aws.amazon.com/transfer/latest/userguide/send-as2-messages.html#file-names-as2
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#server_id ⇒ String
A system-assigned unique identifier for a server instance. This is the specific server that the agreement uses.
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
You can update the status for the agreement, either activating an inactive agreement or the reverse.
6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-transfer/types.rb', line 6967 class UpdateAgreementRequest < Struct.new( :agreement_id, :server_id, :description, :status, :local_profile_id, :partner_profile_id, :base_directory, :access_role, :preserve_filename, :enforce_message_signing, :custom_directories) SENSITIVE = [] include Aws::Structure end |