Class: Aws::Transfer::Types::UpdateCertificateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::UpdateCertificateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_date ⇒ Time
An optional date that specifies when the certificate becomes active.
-
#certificate_id ⇒ String
The identifier of the certificate object that you are updating.
-
#description ⇒ String
A short description to help identify the certificate.
-
#inactive_date ⇒ Time
An optional date that specifies when the certificate becomes inactive.
Instance Attribute Details
#active_date ⇒ Time
An optional date that specifies when the certificate becomes active.
If you do not specify a value, ActiveDate takes the same value as
NotBeforeDate, which is specified by the CA.
7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-transfer/types.rb', line 7107 class UpdateCertificateRequest < Struct.new( :certificate_id, :active_date, :inactive_date, :description) SENSITIVE = [] include Aws::Structure end |
#certificate_id ⇒ String
The identifier of the certificate object that you are updating.
7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-transfer/types.rb', line 7107 class UpdateCertificateRequest < Struct.new( :certificate_id, :active_date, :inactive_date, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A short description to help identify the certificate.
7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-transfer/types.rb', line 7107 class UpdateCertificateRequest < Struct.new( :certificate_id, :active_date, :inactive_date, :description) SENSITIVE = [] include Aws::Structure end |
#inactive_date ⇒ Time
An optional date that specifies when the certificate becomes
inactive. If you do not specify a value, InactiveDate takes the
same value as NotAfterDate, which is specified by the CA.
7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-transfer/types.rb', line 7107 class UpdateCertificateRequest < Struct.new( :certificate_id, :active_date, :inactive_date, :description) SENSITIVE = [] include Aws::Structure end |