Method: Aws::Transfer::Types::UpdateServerRequest#endpoint_details

Defined in:
lib/aws-sdk-transfer/types.rb

#endpoint_detailsTypes::EndpointDetails

The virtual private cloud (VPC) endpoint settings that are configured for your server. When you host your endpoint within your VPC, you can make your endpoint accessible only to resources within your VPC, or you can attach Elastic IP addresses and make your endpoint accessible to clients over the internet. Your VPC’s default security groups are automatically assigned to your endpoint.



7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
7622
7623
# File 'lib/aws-sdk-transfer/types.rb', line 7603

class UpdateServerRequest < Struct.new(
  :certificate,
  :protocol_details,
  :endpoint_details,
  :endpoint_type,
  :host_key,
  :identity_provider_details,
  :logging_role,
  :post_authentication_login_banner,
  :pre_authentication_login_banner,
  :protocols,
  :security_policy_name,
  :server_id,
  :workflow_details,
  :structured_log_destinations,
  :s3_storage_options,
  :ip_address_type,
  :identity_provider_type)
  SENSITIVE = [:host_key]
  include Aws::Structure
end