Method: Aws::Transfer::Types::UpdateServerRequest#protocol_details
- Defined in:
- lib/aws-sdk-transfer/types.rb
#protocol_details ⇒ Types::ProtocolDetails
The protocol settings that are configured for your server.
-
To indicate passive mode (for FTP and FTPS protocols), use the
PassiveIpparameter. Enter a single dotted-quad IPv4 address, such as the external IP address of a firewall, router, or load balancer. -
To ignore the error that is generated when the client attempts to use the
SETSTATcommand on a file that you are uploading to an Amazon S3 bucket, use theSetStatOptionparameter. To have the Transfer Family server ignore theSETSTATcommand and upload files without needing to make any changes to your SFTP client, set the value toENABLE_NO_OP. If you set theSetStatOptionparameter toENABLE_NO_OP, Transfer Family generates a log entry to Amazon CloudWatch Logs, so that you can determine when the client is making aSETSTATcall. -
To determine whether your Transfer Family server resumes recent, negotiated sessions through a unique session ID, use the
TlsSessionResumptionModeparameter. -
As2Transportsindicates the transport method for the AS2 messages. Currently, only HTTP is supported.
6696 6697 6698 6699 6700 6701 6702 6703 6704 6705 6706 6707 6708 6709 6710 6711 6712 6713 6714 |
# File 'lib/aws-sdk-transfer/types.rb', line 6696 class UpdateServerRequest < Struct.new( :certificate, :protocol_details, :endpoint_details, :endpoint_type, :host_key, :identity_provider_details, :logging_role, :post_authentication_login_banner, :pre_authentication_login_banner, :protocols, :security_policy_name, :server_id, :workflow_details, :structured_log_destinations, :s3_storage_options) SENSITIVE = [:host_key] include Aws::Structure end |