Method: Aws::Transfer::Types::UpdateServerRequest#protocols

Defined in:
lib/aws-sdk-transfer/types.rb

#protocolsArray<String>

Specifies the file transfer protocol or protocols over which your file transfer protocol client can connect to your server’s endpoint. The available protocols are:

  • SFTP (Secure Shell (SSH) File Transfer Protocol): File transfer over SSH

  • FTPS (File Transfer Protocol Secure): File transfer with TLS encryption

  • FTP (File Transfer Protocol): Unencrypted file transfer

  • AS2 (Applicability Statement 2): used for transporting structured business-to-business data

<note markdown=“1”> * If you select FTPS, you must choose a certificate stored in

Certificate Manager (ACM) which is used to identify your server
when clients connect to it over FTPS.
  • If Protocol includes either FTP or FTPS, then the EndpointType must be VPC and the IdentityProviderType must be either AWS_DIRECTORY_SERVICE, AWS_LAMBDA, or API_GATEWAY.

  • If Protocol includes FTP, then AddressAllocationIds cannot be associated.

  • If Protocol is set only to SFTP, the EndpointType can be set to PUBLIC and the IdentityProviderType can be set any of the supported identity types: SERVICE_MANAGED, AWS_DIRECTORY_SERVICE, AWS_LAMBDA, or API_GATEWAY.

  • If Protocol includes AS2, then the EndpointType must be VPC, and domain must be Amazon S3.

</note>

Returns:

  • (Array<String>)


6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
6362
6363
6364
6365
# File 'lib/aws-sdk-transfer/types.rb', line 6347

class UpdateServerRequest < Struct.new(
  :certificate,
  :protocol_details,
  :endpoint_details,
  :endpoint_type,
  :host_key,
  :identity_provider_details,
  :logging_role,
  :post_authentication_login_banner,
  :pre_authentication_login_banner,
  :protocols,
  :security_policy_name,
  :server_id,
  :workflow_details,
  :structured_log_destinations,
  :s3_storage_options)
  SENSITIVE = [:host_key]
  include Aws::Structure
end