Class: Aws::Transfer::Types::UpdateWebAppRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::UpdateWebAppRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_endpoint ⇒ String
The
AccessEndpointis the URL that you provide to your users for them to interact with the Transfer Family web app. -
#identity_provider_details ⇒ Types::UpdateWebAppIdentityProviderDetails
Provide updated identity provider values in a
WebAppIdentityProviderDetailsobject. -
#web_app_id ⇒ String
Provide the identifier of the web app that you are updating.
-
#web_app_units ⇒ Types::WebAppUnits
A union that contains the value for number of concurrent connections or the user sessions on your web app.
Instance Attribute Details
#access_endpoint ⇒ String
The AccessEndpoint is the URL that you provide to your users for them to interact with the Transfer Family web app. You can specify a custom URL or use the default value.
6984 6985 6986 6987 6988 6989 6990 6991 |
# File 'lib/aws-sdk-transfer/types.rb', line 6984 class UpdateWebAppRequest < Struct.new( :web_app_id, :identity_provider_details, :access_endpoint, :web_app_units) SENSITIVE = [] include Aws::Structure end |
#identity_provider_details ⇒ Types::UpdateWebAppIdentityProviderDetails
Provide updated identity provider values in a WebAppIdentityProviderDetails object.
6984 6985 6986 6987 6988 6989 6990 6991 |
# File 'lib/aws-sdk-transfer/types.rb', line 6984 class UpdateWebAppRequest < Struct.new( :web_app_id, :identity_provider_details, :access_endpoint, :web_app_units) SENSITIVE = [] include Aws::Structure end |
#web_app_id ⇒ String
Provide the identifier of the web app that you are updating.
6984 6985 6986 6987 6988 6989 6990 6991 |
# File 'lib/aws-sdk-transfer/types.rb', line 6984 class UpdateWebAppRequest < Struct.new( :web_app_id, :identity_provider_details, :access_endpoint, :web_app_units) SENSITIVE = [] include Aws::Structure end |
#web_app_units ⇒ Types::WebAppUnits
A union that contains the value for number of concurrent connections or the user sessions on your web app.
6984 6985 6986 6987 6988 6989 6990 6991 |
# File 'lib/aws-sdk-transfer/types.rb', line 6984 class UpdateWebAppRequest < Struct.new( :web_app_id, :identity_provider_details, :access_endpoint, :web_app_units) SENSITIVE = [] include Aws::Structure end |