Class: Aws::Transfer::Types::WebAppEndpointDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::WebAppEndpointDetails
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Note:
WebAppEndpointDetails is a union - when making an API calls you must set exactly one of the members.
Contains the endpoint configuration for a web app, including VPC settings when the endpoint is hosted within a VPC.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#vpc ⇒ Types::WebAppVpcConfig
The VPC configuration for hosting the web app endpoint within a VPC.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
8029 8030 8031 |
# File 'lib/aws-sdk-transfer/types.rb', line 8029 def unknown @unknown end |
#vpc ⇒ Types::WebAppVpcConfig
The VPC configuration for hosting the web app endpoint within a VPC.
8029 8030 8031 8032 8033 8034 8035 8036 8037 8038 |
# File 'lib/aws-sdk-transfer/types.rb', line 8029 class WebAppEndpointDetails < Struct.new( :vpc, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Vpc < WebAppEndpointDetails; end class Unknown < WebAppEndpointDetails; end end |