Class: Aws::Transfer::Types::WebAppUnits

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Note:

WebAppUnits is a union - when making an API calls you must set exactly one of the members.

Note:

WebAppUnits is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of WebAppUnits corresponding to the set member.

Contains an integer value that represents the value for number of concurrent connections or the user sessions on your web app.

Defined Under Namespace

Classes: Provisioned, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#provisionedInteger

An integer that represents the number of units for your desired number of concurrent connections, or the number of user sessions on your web app at the same time.

Each increment allows an additional 250 concurrent sessions: a value of 1 sets the number of concurrent sessions to 250; 2 sets a value of 500, and so on.

Returns:

  • (Integer)


8154
8155
8156
8157
8158
8159
8160
8161
8162
8163
# File 'lib/aws-sdk-transfer/types.rb', line 8154

class WebAppUnits < Struct.new(
  :provisioned,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Provisioned < WebAppUnits; end
  class Unknown < WebAppUnits; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



8154
8155
8156
# File 'lib/aws-sdk-transfer/types.rb', line 8154

def unknown
  @unknown
end