Class: Aws::Transfer::Types::WebAppVpcConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Contains the VPC configuration settings for hosting a web app endpoint, including the VPC ID, subnet IDs, and security group IDs for access control.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ip_address_typeString

The IP address type for the web app’s VPC endpoint. This determines whether the endpoint is accessible over IPv4 only, or over both IPv4 and IPv6.

Returns:

  • (String)


8120
8121
8122
8123
8124
8125
8126
8127
# File 'lib/aws-sdk-transfer/types.rb', line 8120

class WebAppVpcConfig < Struct.new(
  :subnet_ids,
  :vpc_id,
  :security_group_ids,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The list of security group IDs that control access to the web app endpoint. These security groups determine which sources can access the endpoint based on IP addresses and port configurations.

Returns:

  • (Array<String>)


8120
8121
8122
8123
8124
8125
8126
8127
# File 'lib/aws-sdk-transfer/types.rb', line 8120

class WebAppVpcConfig < Struct.new(
  :subnet_ids,
  :vpc_id,
  :security_group_ids,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The list of subnet IDs within the VPC where the web app endpoint will be deployed. These subnets must be in the same VPC specified in the VpcId parameter.

Returns:

  • (Array<String>)


8120
8121
8122
8123
8124
8125
8126
8127
# File 'lib/aws-sdk-transfer/types.rb', line 8120

class WebAppVpcConfig < Struct.new(
  :subnet_ids,
  :vpc_id,
  :security_group_ids,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The identifier of the VPC where the web app endpoint will be hosted.

Returns:

  • (String)


8120
8121
8122
8123
8124
8125
8126
8127
# File 'lib/aws-sdk-transfer/types.rb', line 8120

class WebAppVpcConfig < Struct.new(
  :subnet_ids,
  :vpc_id,
  :security_group_ids,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end