Class: Aws::Transfer::Types::WorkflowDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Specifies the workflow ID for the workflow to assign and the execution role that’s used for executing the workflow.

In addition to a workflow to execute when a file is uploaded completely, WorkflowDetails can also contain a workflow ID (and execution role) for a workflow to execute on partial upload. A partial upload occurs when the server session disconnects while the file is still being uploaded.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_roleString

Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources



8112
8113
8114
8115
8116
8117
# File 'lib/aws-sdk-transfer/types.rb', line 8112

class WorkflowDetail < Struct.new(
  :workflow_id,
  :execution_role)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_idString

A unique identifier for the workflow.



8112
8113
8114
8115
8116
8117
# File 'lib/aws-sdk-transfer/types.rb', line 8112

class WorkflowDetail < Struct.new(
  :workflow_id,
  :execution_role)
  SENSITIVE = []
  include Aws::Structure
end