Class: Aws::Transfer::Types::CreateWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::CreateWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A textual description for the workflow.
-
#on_exception_steps ⇒ Array<Types::WorkflowStep>
Specifies the steps (actions) to take if errors are encountered during execution of the workflow.
-
#steps ⇒ Array<Types::WorkflowStep>
Specifies the details for the steps that are in the specified workflow.
-
#tags ⇒ Array<Types::Tag>
Key-value pairs that can be used to group and search for workflows.
Instance Attribute Details
#description ⇒ String
A textual description for the workflow.
1225 1226 1227 1228 1229 1230 1231 1232 |
# File 'lib/aws-sdk-transfer/types.rb', line 1225 class CreateWorkflowRequest < Struct.new( :description, :steps, :on_exception_steps, :tags) SENSITIVE = [] include Aws::Structure end |
#on_exception_steps ⇒ Array<Types::WorkflowStep>
Specifies the steps (actions) to take if errors are encountered during execution of the workflow.
<note markdown=“1”> For custom steps, the Lambda function needs to send FAILURE to the call back API to kick off the exception steps. Additionally, if the Lambda does not send SUCCESS before it times out, the exception steps are executed.
</note>
1225 1226 1227 1228 1229 1230 1231 1232 |
# File 'lib/aws-sdk-transfer/types.rb', line 1225 class CreateWorkflowRequest < Struct.new( :description, :steps, :on_exception_steps, :tags) SENSITIVE = [] include Aws::Structure end |
#steps ⇒ Array<Types::WorkflowStep>
Specifies the details for the steps that are in the specified workflow.
The TYPE specifies which of the following actions is being taken for this step.
-
COPY- Copy the file to another location. -
CUSTOM- Perform a custom step with an Lambda function target. -
DECRYPT- Decrypt a file that was encrypted before it was uploaded. -
DELETE- Delete the file. -
TAG- Add a tag to the file.
<note markdown=“1”> Currently, copying and tagging are supported only on S3.
</note>
For file location, you specify either the Amazon S3 bucket and key, or the Amazon EFS file system ID and path.
1225 1226 1227 1228 1229 1230 1231 1232 |
# File 'lib/aws-sdk-transfer/types.rb', line 1225 class CreateWorkflowRequest < Struct.new( :description, :steps, :on_exception_steps, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Key-value pairs that can be used to group and search for workflows. Tags are metadata attached to workflows for any purpose.
1225 1226 1227 1228 1229 1230 1231 1232 |
# File 'lib/aws-sdk-transfer/types.rb', line 1225 class CreateWorkflowRequest < Struct.new( :description, :steps, :on_exception_steps, :tags) SENSITIVE = [] include Aws::Structure end |