Method: Aws::Transfer::Types::DescribedSecurityPolicy#tls_ciphers
- Defined in:
- lib/aws-sdk-transfer/types.rb
#tls_ciphers ⇒ Array<String>
Lists the enabled Transport Layer Security (TLS) cipher encryption algorithms in the security policy that is attached to the server.
<note markdown=“1”> This parameter only applies to security policies for servers.
</note>
3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-transfer/types.rb', line 3095 class DescribedSecurityPolicy < Struct.new( :fips, :security_policy_name, :ssh_ciphers, :ssh_kexs, :ssh_macs, :tls_ciphers, :ssh_host_key_algorithms, :type, :protocols) SENSITIVE = [] include Aws::Structure end |