Class: Aws::Transfer::Types::ImportCertificateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:certificate, :certificate_chain, :private_key]

Instance Attribute Summary collapse

Instance Attribute Details

#active_dateTime

An optional date that specifies when the certificate becomes active. If you do not specify a value, ActiveDate takes the same value as NotBeforeDate, which is specified by the CA.

Returns:

  • (Time)


4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-transfer/types.rb', line 4266

class ImportCertificateRequest < Struct.new(
  :usage,
  :certificate,
  :certificate_chain,
  :private_key,
  :active_date,
  :inactive_date,
  :description,
  :tags)
  SENSITIVE = [:certificate, :certificate_chain, :private_key]
  include Aws::Structure
end

#certificateString

  • For the CLI, provide a file path for a certificate in URI format. For example, --certificate file://encryption-cert.pem. Alternatively, you can provide the raw content.

  • For the SDK, specify the raw content of a certificate file. For example, --certificate "`cat encryption-cert.pem`".

You can provide both the certificate and its chain in this parameter, without needing to use the CertificateChain parameter. If you use this parameter for both the certificate and its chain, do not use the CertificateChain parameter.

Returns:

  • (String)


4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-transfer/types.rb', line 4266

class ImportCertificateRequest < Struct.new(
  :usage,
  :certificate,
  :certificate_chain,
  :private_key,
  :active_date,
  :inactive_date,
  :description,
  :tags)
  SENSITIVE = [:certificate, :certificate_chain, :private_key]
  include Aws::Structure
end

#certificate_chainString

An optional list of certificates that make up the chain for the certificate that's being imported.

Returns:

  • (String)


4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-transfer/types.rb', line 4266

class ImportCertificateRequest < Struct.new(
  :usage,
  :certificate,
  :certificate_chain,
  :private_key,
  :active_date,
  :inactive_date,
  :description,
  :tags)
  SENSITIVE = [:certificate, :certificate_chain, :private_key]
  include Aws::Structure
end

#descriptionString

A short description that helps identify the certificate.

Returns:

  • (String)


4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-transfer/types.rb', line 4266

class ImportCertificateRequest < Struct.new(
  :usage,
  :certificate,
  :certificate_chain,
  :private_key,
  :active_date,
  :inactive_date,
  :description,
  :tags)
  SENSITIVE = [:certificate, :certificate_chain, :private_key]
  include Aws::Structure
end

#inactive_dateTime

An optional date that specifies when the certificate becomes inactive. If you do not specify a value, InactiveDate takes the same value as NotAfterDate, which is specified by the CA.

Returns:

  • (Time)


4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-transfer/types.rb', line 4266

class ImportCertificateRequest < Struct.new(
  :usage,
  :certificate,
  :certificate_chain,
  :private_key,
  :active_date,
  :inactive_date,
  :description,
  :tags)
  SENSITIVE = [:certificate, :certificate_chain, :private_key]
  include Aws::Structure
end

#private_keyString

  • For the CLI, provide a file path for a private key in URI format. For example, --private-key file://encryption-key.pem. Alternatively, you can provide the raw content of the private key file.

  • For the SDK, specify the raw content of a private key file. For example, --private-key "`cat encryption-key.pem`"

Returns:

  • (String)


4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-transfer/types.rb', line 4266

class ImportCertificateRequest < Struct.new(
  :usage,
  :certificate,
  :certificate_chain,
  :private_key,
  :active_date,
  :inactive_date,
  :description,
  :tags)
  SENSITIVE = [:certificate, :certificate_chain, :private_key]
  include Aws::Structure
end

#tagsArray<Types::Tag>

Key-value pairs that can be used to group and search for certificates.

Returns:



4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-transfer/types.rb', line 4266

class ImportCertificateRequest < Struct.new(
  :usage,
  :certificate,
  :certificate_chain,
  :private_key,
  :active_date,
  :inactive_date,
  :description,
  :tags)
  SENSITIVE = [:certificate, :certificate_chain, :private_key]
  include Aws::Structure
end

#usageString

Specifies how this certificate is used. It can be used in the following ways:

  • SIGNING: For signing AS2 messages

  • ENCRYPTION: For encrypting AS2 messages

  • TLS: For securing AS2 communications sent over HTTPS

Returns:

  • (String)


4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-transfer/types.rb', line 4266

class ImportCertificateRequest < Struct.new(
  :usage,
  :certificate,
  :certificate_chain,
  :private_key,
  :active_date,
  :inactive_date,
  :description,
  :tags)
  SENSITIVE = [:certificate, :certificate_chain, :private_key]
  include Aws::Structure
end