Class: Aws::Transfer::Types::ListCertificatesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of items to return.

Returns:

  • (Integer)


4546
4547
4548
4549
4550
4551
# File 'lib/aws-sdk-transfer/types.rb', line 4546

class ListCertificatesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

When you can get additional results from the ListCertificates call, a NextToken parameter is returned in the output. You can then pass in a subsequent command to the NextToken parameter to continue listing additional certificates.

Returns:

  • (String)


4546
4547
4548
4549
4550
4551
# File 'lib/aws-sdk-transfer/types.rb', line 4546

class ListCertificatesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end