Class: Aws::Transfer::Types::ListFileTransferResultsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::ListFileTransferResultsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_id ⇒ String
A unique identifier for a connector.
-
#max_results ⇒ Integer
The maximum number of files to return in a single page.
-
#next_token ⇒ String
If there are more file details than returned in this call, use this value for a subsequent call to
ListFileTransferResultsto retrieve them. -
#transfer_id ⇒ String
A unique identifier for a file transfer.
Instance Attribute Details
#connector_id ⇒ String
A unique identifier for a connector. This value should match the
value supplied to the corresponding StartFileTransfer call.
4722 4723 4724 4725 4726 4727 4728 4729 |
# File 'lib/aws-sdk-transfer/types.rb', line 4722 class ListFileTransferResultsRequest < Struct.new( :connector_id, :transfer_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of files to return in a single page. Note that currently you can specify a maximum of 10 file paths in a single StartFileTransfer operation. Thus, the maximum number of file transfer results that can be returned in a single page is 10.
4722 4723 4724 4725 4726 4727 4728 4729 |
# File 'lib/aws-sdk-transfer/types.rb', line 4722 class ListFileTransferResultsRequest < Struct.new( :connector_id, :transfer_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are more file details than returned in this call, use this
value for a subsequent call to ListFileTransferResults to retrieve
them.
4722 4723 4724 4725 4726 4727 4728 4729 |
# File 'lib/aws-sdk-transfer/types.rb', line 4722 class ListFileTransferResultsRequest < Struct.new( :connector_id, :transfer_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#transfer_id ⇒ String
A unique identifier for a file transfer. This value should match the
value supplied to the corresponding StartFileTransfer call.
4722 4723 4724 4725 4726 4727 4728 4729 |
# File 'lib/aws-sdk-transfer/types.rb', line 4722 class ListFileTransferResultsRequest < Struct.new( :connector_id, :transfer_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |