Class: Aws::Transfer::Types::ListProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::ListProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return.
-
#next_token ⇒ String
When there are additional results that were not returned, a
NextTokenparameter is returned. -
#profile_type ⇒ String
Indicates whether to list only
LOCALtype profiles or onlyPARTNERtype profiles.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return.
4815 4816 4817 4818 4819 4820 4821 |
# File 'lib/aws-sdk-transfer/types.rb', line 4815 class ListProfilesRequest < Struct.new( :max_results, :next_token, :profile_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When there are additional results that were not returned, a NextToken parameter is returned. You can use that value for a subsequent call to ListProfiles to continue listing results.
4815 4816 4817 4818 4819 4820 4821 |
# File 'lib/aws-sdk-transfer/types.rb', line 4815 class ListProfilesRequest < Struct.new( :max_results, :next_token, :profile_type) SENSITIVE = [] include Aws::Structure end |
#profile_type ⇒ String
Indicates whether to list only LOCAL type profiles or only PARTNER type profiles. If not supplied in the request, the command lists all types of profiles.
4815 4816 4817 4818 4819 4820 4821 |
# File 'lib/aws-sdk-transfer/types.rb', line 4815 class ListProfilesRequest < Struct.new( :max_results, :next_token, :profile_type) SENSITIVE = [] include Aws::Structure end |