Class: Aws::Transfer::Types::SftpConnectorConnectionDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Contains the details for an SFTP connector connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#host_keyString

The SSH public key of the remote SFTP server. This is returned during the initial connection attempt when you call TestConnection. It allows you to retrieve the valid server host key to update the connector when you are unable to obtain it in advance.

Returns:

  • (String)


6213
6214
6215
6216
6217
# File 'lib/aws-sdk-transfer/types.rb', line 6213

class SftpConnectorConnectionDetails < Struct.new(
  :host_key)
  SENSITIVE = []
  include Aws::Structure
end