Class: Aws::Transfer::Types::StartFileTransferRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::StartFileTransferRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_id ⇒ String
The unique identifier for the connector.
-
#local_directory_path ⇒ String
For an inbound transfer, the
LocaDirectoryPathspecifies the destination for one or more files that are transferred from the partner’s SFTP server. -
#remote_directory_path ⇒ String
For an outbound transfer, the
RemoteDirectoryPathspecifies the destination for one or more files that are transferred to the partner’s SFTP server. -
#retrieve_file_paths ⇒ Array<String>
One or more source paths for the partner’s SFTP server.
-
#send_file_paths ⇒ Array<String>
One or more source paths for the Amazon S3 storage.
Instance Attribute Details
#connector_id ⇒ String
The unique identifier for the connector.
5667 5668 5669 5670 5671 5672 5673 5674 5675 |
# File 'lib/aws-sdk-transfer/types.rb', line 5667 class StartFileTransferRequest < Struct.new( :connector_id, :send_file_paths, :retrieve_file_paths, :local_directory_path, :remote_directory_path) SENSITIVE = [] include Aws::Structure end |
#local_directory_path ⇒ String
For an inbound transfer, the LocaDirectoryPath specifies the destination for one or more files that are transferred from the partner’s SFTP server.
5667 5668 5669 5670 5671 5672 5673 5674 5675 |
# File 'lib/aws-sdk-transfer/types.rb', line 5667 class StartFileTransferRequest < Struct.new( :connector_id, :send_file_paths, :retrieve_file_paths, :local_directory_path, :remote_directory_path) SENSITIVE = [] include Aws::Structure end |
#remote_directory_path ⇒ String
For an outbound transfer, the RemoteDirectoryPath specifies the destination for one or more files that are transferred to the partner’s SFTP server. If you don’t specify a RemoteDirectoryPath, the destination for transferred files is the SFTP user’s home directory.
5667 5668 5669 5670 5671 5672 5673 5674 5675 |
# File 'lib/aws-sdk-transfer/types.rb', line 5667 class StartFileTransferRequest < Struct.new( :connector_id, :send_file_paths, :retrieve_file_paths, :local_directory_path, :remote_directory_path) SENSITIVE = [] include Aws::Structure end |
#retrieve_file_paths ⇒ Array<String>
One or more source paths for the partner’s SFTP server. Each string represents a source file path for one inbound file transfer.
5667 5668 5669 5670 5671 5672 5673 5674 5675 |
# File 'lib/aws-sdk-transfer/types.rb', line 5667 class StartFileTransferRequest < Struct.new( :connector_id, :send_file_paths, :retrieve_file_paths, :local_directory_path, :remote_directory_path) SENSITIVE = [] include Aws::Structure end |
#send_file_paths ⇒ Array<String>
One or more source paths for the Amazon S3 storage. Each string represents a source file path for one outbound file transfer. For example, ‘ amzn-s3-demo-bucket/myfile.txt `.
<note markdown=“1”> Replace ‘ amzn-s3-demo-bucket ` with one of your actual buckets.
</note>
5667 5668 5669 5670 5671 5672 5673 5674 5675 |
# File 'lib/aws-sdk-transfer/types.rb', line 5667 class StartFileTransferRequest < Struct.new( :connector_id, :send_file_paths, :retrieve_file_paths, :local_directory_path, :remote_directory_path) SENSITIVE = [] include Aws::Structure end |