Class: Aws::Transfer::Types::UpdateAccessResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::UpdateAccessResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#external_id ⇒ String
The external identifier of the group whose users have access to your Amazon S3 or Amazon EFS resources over the enabled protocols using Amazon Web ServicesTransfer Family.
-
#server_id ⇒ String
The identifier of the server that the user is attached to.
Instance Attribute Details
#external_id ⇒ String
The external identifier of the group whose users have access to your Amazon S3 or Amazon EFS resources over the enabled protocols using Amazon Web ServicesTransfer Family.
6110 6111 6112 6113 6114 6115 |
# File 'lib/aws-sdk-transfer/types.rb', line 6110 class UpdateAccessResponse < Struct.new( :server_id, :external_id) SENSITIVE = [] include Aws::Structure end |
#server_id ⇒ String
The identifier of the server that the user is attached to.
6110 6111 6112 6113 6114 6115 |
# File 'lib/aws-sdk-transfer/types.rb', line 6110 class UpdateAccessResponse < Struct.new( :server_id, :external_id) SENSITIVE = [] include Aws::Structure end |