Class: Aws::Transfer::Types::UpdateConnectorEgressConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::UpdateConnectorEgressConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Note:
UpdateConnectorEgressConfig is a union - when making an API calls you must set exactly one of the members.
Structure for updating the egress configuration of an existing connector. Allows modification of how traffic is routed from the connector to the SFTP server, including VPC_LATTICE settings.
Direct Known Subclasses
Defined Under Namespace
Classes: Unknown, VpcLattice
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#vpc_lattice ⇒ Types::UpdateConnectorVpcLatticeEgressConfig
VPC_LATTICE configuration updates for the connector.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
7054 7055 7056 |
# File 'lib/aws-sdk-transfer/types.rb', line 7054 def unknown @unknown end |
#vpc_lattice ⇒ Types::UpdateConnectorVpcLatticeEgressConfig
VPC_LATTICE configuration updates for the connector. Use this to modify the Resource Configuration ARN or port number for VPC-based connectivity.
7054 7055 7056 7057 7058 7059 7060 7061 7062 7063 |
# File 'lib/aws-sdk-transfer/types.rb', line 7054 class UpdateConnectorEgressConfig < Struct.new( :vpc_lattice, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class VpcLattice < UpdateConnectorEgressConfig; end class Unknown < UpdateConnectorEgressConfig; end end |