Class: Aws::Transfer::Types::UpdateWebAppVpcConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transfer/types.rb

Overview

Contains the VPC configuration settings for updating a web app endpoint, including the subnet IDs where the endpoint should be deployed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ip_address_typeString

The IP address type for the web app’s VPC endpoint. This determines whether the endpoint is accessible over IPv4 only, or over both IPv4 and IPv6.

Returns:

  • (String)


7984
7985
7986
7987
7988
7989
# File 'lib/aws-sdk-transfer/types.rb', line 7984

class UpdateWebAppVpcConfig < Struct.new(
  :subnet_ids,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The list of subnet IDs within the VPC where the web app endpoint should be deployed during the update operation.

Returns:

  • (Array<String>)


7984
7985
7986
7987
7988
7989
# File 'lib/aws-sdk-transfer/types.rb', line 7984

class UpdateWebAppVpcConfig < Struct.new(
  :subnet_ids,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end