Class: Aws::Transfer::Types::WorkflowDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Transfer::Types::WorkflowDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transfer/types.rb
Overview
Specifies the workflow ID for the workflow to assign and the execution role that’s used for executing the workflow.
In addition to a workflow to execute when a file is uploaded completely, ‘WorkflowDetails` can also contain a workflow ID (and execution role) for a workflow to execute on partial upload. A partial upload occurs when the server session disconnects while the file is still being uploaded.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_role ⇒ String
Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources.
-
#workflow_id ⇒ String
A unique identifier for the workflow.
Instance Attribute Details
#execution_role ⇒ String
Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources
8150 8151 8152 8153 8154 8155 |
# File 'lib/aws-sdk-transfer/types.rb', line 8150 class WorkflowDetail < Struct.new( :workflow_id, :execution_role) SENSITIVE = [] include Aws::Structure end |
#workflow_id ⇒ String
A unique identifier for the workflow.
8150 8151 8152 8153 8154 8155 |
# File 'lib/aws-sdk-transfer/types.rb', line 8150 class WorkflowDetail < Struct.new( :workflow_id, :execution_role) SENSITIVE = [] include Aws::Structure end |